@@ -1,9 +1,9 @@
 /***************************************************************************
-    smb4kbasicnetworkitem  -  This class provides the basic network item
-    for the core library of Smb4K.
+    This class provides the basic network item for the core library of 
+    Smb4K.
                              -------------------
     begin                : Do Apr 2 2009
-    copyright            : (C) 2009-2015 by Alexander Reinholdt
+    copyright            : (C) 2009-2016 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -31,12 +31,9 @@
 #include "smb4kglobal.h"
 
 // Qt includes
-#include <QtCore/QString>
-#include <QtCore/QScopedPointer>
-#include <QtGui/QIcon>
-
-// KDE includes
-#include <kdemacros.h>
+#include <QString>
+#include <QScopedPointer>
+#include <QIcon>
 
 // forward declarations
 class Smb4KBasicNetworkItemPrivate;
@@ -51,18 +48,18 @@ using namespace Smb4KGlobal;
  * @since 1.0.0
  */
 
-class KDE_EXPORT Smb4KBasicNetworkItem
+class Q_DECL_EXPORT Smb4KBasicNetworkItem
 {
   public:
     /**
      * The constructor
      */
-    explicit Smb4KBasicNetworkItem( NetworkItem type = Unknown );
+    explicit Smb4KBasicNetworkItem(NetworkItem type = UnknownNetworkItem);
 
     /**
      * The copy constructor
      */
-    Smb4KBasicNetworkItem( const Smb4KBasicNetworkItem &item );
+    Smb4KBasicNetworkItem(const Smb4KBasicNetworkItem &item);
     
     /**
      * The destructor
@@ -83,7 +80,7 @@ class KDE_EXPORT Smb4KBasicNetworkItem
      *
      * @param key           The key
      */
-    void setKey( const QString &key );
+    void setKey(const QString &key);
 
     /**
      * This function returns the key for this network item. By default,
@@ -98,7 +95,7 @@ class KDE_EXPORT Smb4KBasicNetworkItem
      * 
      * @param icon          The icon
      */
-    void setIcon( const QIcon &icon );
+    void setIcon(const QIcon &icon);
     
     /**
      * This function returns the icon of the network item. By default, it
