@@ -1,8 +1,8 @@
 /***************************************************************************
-    smb4kcustomoptions - This class carries custom options
+    This class carries custom options
                              -------------------
     begin                : Fr 29 Apr 2011
-    copyright            : (C) 2011-2015 by Alexander Reinholdt
+    copyright            : (C) 2011-2016 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -31,18 +31,18 @@
 #include "smb4kcustomoptions.h"
 
 // Qt includes
-#include <QtCore/QDebug>
-#include <QtNetwork/QHostAddress>
+#include <QDebug>
+#include <QHostAddress>
 
 // KDE includes
-#include <kuser.h>
+#include <KCoreAddons/KUser>
 
 
 class Smb4KCustomOptionsPrivate
 {
   public:
     QString workgroup;
-    KUrl url;
+    QUrl url;
     QHostAddress ip;
     NetworkItem type;
     Smb4KCustomOptions::Remount remount;
@@ -53,7 +53,6 @@ class Smb4KCustomOptionsPrivate
     Smb4KCustomOptions::SecurityMode securityMode;
     Smb4KCustomOptions::WriteAccess writeAccess;
 #endif
-    Smb4KCustomOptions::ProtocolHint protocolHint;
     Smb4KCustomOptions::Kerberos kerberos;
     KUser user;
     KUserGroup group;
@@ -76,7 +75,6 @@ Smb4KCustomOptions::Smb4KCustomOptions(Smb4KHost *host)
   d->securityMode   = UndefinedSecurityMode;
   d->writeAccess    = UndefinedWriteAccess;
 #endif
-  d->protocolHint   = UndefinedProtocolHint;
   d->kerberos       = UndefinedKerberos;
   d->user           = KUser(KUser::UseRealUserID);
   d->group          = KUserGroup(KUser::UseRealUserID);
@@ -98,10 +96,9 @@ Smb4KCustomOptions::Smb4KCustomOptions(Smb4KShare *share)
   d->securityMode   = UndefinedSecurityMode;
   d->writeAccess    = UndefinedWriteAccess;
 #endif
-  d->protocolHint   = UndefinedProtocolHint;
   d->kerberos       = UndefinedKerberos;
-  d->user           = KUser(share->uid());
-  d->group          = KUserGroup(share->gid());
+  d->user           = share->user();
+  d->group          = share->group();
   d->ip.setAddress(share->hostIP());
   d->wol_first_scan = false;
   d->wol_mount      = false;
@@ -118,7 +115,7 @@ Smb4KCustomOptions::Smb4KCustomOptions(const Smb4KCustomOptions &o)
 Smb4KCustomOptions::Smb4KCustomOptions()
 : d(new Smb4KCustomOptionsPrivate)
 {
-  d->type           = Unknown;
+  d->type           = UnknownNetworkItem;
   d->remount        = UndefinedRemount;
   d->smbPort        = 139;
 #if defined(Q_OS_LINUX)
@@ -126,7 +123,6 @@ Smb4KCustomOptions::Smb4KCustomOptions()
   d->securityMode   = UndefinedSecurityMode;
   d->writeAccess    = UndefinedWriteAccess;
 #endif
-  d->protocolHint   = UndefinedProtocolHint;
   d->kerberos       = UndefinedKerberos;
   d->user           = KUser(KUser::UseRealUserID);
   d->group          = KUserGroup(KUser::UseRealUserID);
@@ -146,7 +142,7 @@ void Smb4KCustomOptions::setHost(Smb4KHost *host)
   
   switch (d->type)
   {
-    case Unknown:
+    case UnknownNetworkItem:
     {
       d->workgroup      = host->workgroupName();
       d->url            = host->url();
@@ -172,17 +168,17 @@ void Smb4KCustomOptions::setShare(Smb4KShare *share)
   
   switch (d->type)
   {
-    case Unknown:
+    case UnknownNetworkItem:
     {
-      d->url            = share->url();
-      d->workgroup      = share->workgroupName();
-      d->type           = Share;
-      d->smbPort        = 139;
+      d->url = share->url();
+      d->workgroup = share->workgroupName();
+      d->type = Share;
+      d->smbPort = 139;
 #if defined(Q_OS_LINUX)
       d->fileSystemPort = share->port() != -1 ? share->port() : 445;
 #endif
-      d->user           = KUser(share->uid());
-      d->group          = KUserGroup(share->gid());
+      d->user = share->user();
+      d->group = share->group();
       d->ip.setAddress(share->hostIP());
       break;
     }
@@ -190,13 +186,13 @@ void Smb4KCustomOptions::setShare(Smb4KShare *share)
     {
       if (QString::compare(unc(), share->hostUNC(), Qt::CaseInsensitive) == 0)
       {
-        d->url            = share->url();
-        d->type           = Share;
+        d->url = share->url();
+        d->type = Share;
 #if defined(Q_OS_LINUX)
         d->fileSystemPort = share->port() != -1 ? share->port() : d->fileSystemPort;
 #endif
-        d->user           = KUser(share->uid());
-        d->group          = KUserGroup(share->gid());
+        d->user = share->user();
+        d->group = share->group();
         d->ip.setAddress(share->hostIP());
       }
       else
@@ -266,7 +262,7 @@ QString Smb4KCustomOptions::workgroupName() const
 }
 
 
-void Smb4KCustomOptions::setURL(const KUrl &url)
+void Smb4KCustomOptions::setURL(const QUrl &url)
 {
   d->url = url;
 }
@@ -274,12 +270,12 @@ void Smb4KCustomOptions::setURL(const KUrl &url)
 
 void Smb4KCustomOptions::setURL(const QString &url)
 {
-  d->url.setUrl(url, KUrl::TolerantMode);
-  d->url.setProtocol("smb");
+  d->url.setUrl(url, QUrl::TolerantMode);
+  d->url.setScheme("smb");
 }
 
 
-KUrl Smb4KCustomOptions::url() const
+QUrl Smb4KCustomOptions::url() const
 {
   return d->url;
 }
@@ -434,18 +430,6 @@ Smb4KCustomOptions::WriteAccess Smb4KCustomOptions::writeAccess() const
 #endif
 
 
-void Smb4KCustomOptions::setProtocolHint(Smb4KCustomOptions::ProtocolHint protocol)
-{
-  d->protocolHint = protocol;
-}
-
-
-Smb4KCustomOptions::ProtocolHint Smb4KCustomOptions::protocolHint() const
-{
-  return d->protocolHint;
-}
-
-
 void Smb4KCustomOptions::setUseKerberos(Smb4KCustomOptions::Kerberos kerberos)
 {
   d->kerberos = kerberos;
@@ -458,39 +442,27 @@ Smb4KCustomOptions::Kerberos Smb4KCustomOptions::useKerberos() const
 }
 
 
-void Smb4KCustomOptions::setUID(K_UID uid)
+void Smb4KCustomOptions::setUser(const KUser &user)
 {
-  d->user = KUser(uid);
+  d->user = user;
 }
 
 
-K_UID Smb4KCustomOptions::uid() const
+KUser Smb4KCustomOptions::user() const
 {
-  return d->user.uid();
+  return d->user;
 }
 
 
-QString Smb4KCustomOptions::owner() const
+void Smb4KCustomOptions::setGroup(const KUserGroup& group)
 {
-  return d->user.loginName();
+  d->group = group;
 }
 
 
-void Smb4KCustomOptions::setGID(K_GID gid)
+KUserGroup Smb4KCustomOptions::group() const
 {
-  d->group = KUserGroup(gid);
-}
-
-
-K_GID Smb4KCustomOptions::gid() const
-{
-  return d->group.gid();
-}
-
-
-QString Smb4KCustomOptions::group() const
-{
-  return d->group.name();
+  return d->group;
 }
 
 
@@ -648,39 +620,6 @@ QMap<QString, QString> Smb4KCustomOptions::customOptions() const
   }
 #endif
 
-  switch (d->protocolHint)
-  {
-    case Automatic:
-    {
-      entries.insert("protocol", "auto");
-      break;
-    }
-    case RPC:
-    {
-      entries.insert("protocol", "rpc");
-      break;
-    }
-    case RAP:
-    {
-      entries.insert("protocol", "rap");
-      break;
-    }
-    case ADS:
-    {
-      entries.insert("protocol", "ads");
-      break;
-    }
-    case UndefinedProtocolHint:
-    {
-      entries.insert("protocol", QString());
-      break;
-    }
-    default:
-    {
-      break;
-    }
-  }
-
   switch (d->kerberos)
   {
     case UseKerberos:
@@ -704,9 +643,9 @@ QMap<QString, QString> Smb4KCustomOptions::customOptions() const
     }
   }
   
-  entries.insert("uid", QString("%1").arg(d->user.uid()));
+  entries.insert("uid", QString("%1").arg(d->user.userId().toString()));
   entries.insert("owner", d->user.loginName());
-  entries.insert("gid", QString("%1").arg(d->group.gid()));
+  entries.insert("gid", QString("%1").arg(d->group.groupId().toString()));
   entries.insert("group", d->group.name());
   entries.insert("mac_address", d->mac);
   entries.insert("wol_send_before_first_scan", d->wol_first_scan ? "true" : "false");
@@ -823,16 +762,6 @@ bool Smb4KCustomOptions::equals(Smb4KCustomOptions *options, bool fullCheck) con
     }
 #endif
 
-    // Protocol hint
-    if (d->protocolHint != options->protocolHint())
-    {
-      return false;
-    }
-    else
-    {
-      // Do nothing
-    }
-    
     // Kerberos
     if (d->kerberos != options->useKerberos())
     {
@@ -844,7 +773,7 @@ bool Smb4KCustomOptions::equals(Smb4KCustomOptions *options, bool fullCheck) con
     }
     
     // UID
-    if (d->user.uid() != options->uid())
+    if (d->user.userId() != options->user().userId())
     {
       return false;
     }
@@ -854,7 +783,7 @@ bool Smb4KCustomOptions::equals(Smb4KCustomOptions *options, bool fullCheck) con
     }
     
     // GID
-    if (d->group.gid() != options->gid())
+    if (d->group.groupId() != options->group().groupId())
     {
       return false;
     }
@@ -905,7 +834,7 @@ bool Smb4KCustomOptions::equals(Smb4KCustomOptions *options, bool fullCheck) con
 bool Smb4KCustomOptions::isEmpty()
 {
   // Type
-  if (d->type != Unknown)
+  if (d->type != UnknownNetworkItem)
   {
     return false;
   }
@@ -1006,16 +935,6 @@ bool Smb4KCustomOptions::isEmpty()
   }
 #endif
 
-  // Protocol hint
-  if (d->protocolHint != UndefinedProtocolHint)
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-  
   // Kerberos
   if (d->kerberos != UndefinedKerberos)
   {
@@ -1027,7 +946,7 @@ bool Smb4KCustomOptions::isEmpty()
   }
   
   // UID
-  if (d->user.uid() != KUser(KUser::UseRealUserID).uid())
+  if (d->user.userId() != KUser(KUser::UseRealUserID).userId())
   {
     return false;
   }
@@ -1037,7 +956,7 @@ bool Smb4KCustomOptions::isEmpty()
   }
   
   // GID
-  if (d->group.gid() != KUserGroup(KUser::UseRealUserID).gid())
+  if (d->group.groupId() != KUserGroup(KUser::UseRealUserID).groupId())
   {
     return false;
   }
