@@ -1,8 +1,8 @@
 /***************************************************************************
-    smb4kcustomoptions - This class carries custom options
+    This class carries custom options
                              -------------------
     begin                : Fr 29 Apr 2011
-    copyright            : (C) 2011-2015 by Alexander Reinholdt
+    copyright            : (C) 2011-2016 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -32,11 +32,11 @@
 #include "smb4kglobal.h"
 
 // Qt includes
-#include <QtCore/QScopedPointer>
+#include <QScopedPointer>
+#include <QUrl>
 
 // KDE includes
-#include <kdemacros.h>
-#include <kurl.h>
+#include <KCoreAddons/KUser>
 
 // forward declarations
 class Smb4KCustomOptionsPrivate;
@@ -51,7 +51,7 @@ using namespace Smb4KGlobal;
  * @since 1.0.0
  */
 
-class KDE_EXPORT Smb4KCustomOptions
+class Q_DECL_EXPORT Smb4KCustomOptions
 {
   friend class Smb4KCustomOptionsPrivate;
   
@@ -61,7 +61,7 @@ class KDE_EXPORT Smb4KCustomOptions
      * 
      * @param RemountOnce       Remount the share only next time the application
      *                          is started.
-     * @param RemountAlways     Remount the share everytime the application is
+     * @param RemountAlways     Remount the share every time the application is
      *                          started.
      * @param RemountNever      Never remount the share.
      * @param UndefinedRemount  No remount option is defined.
@@ -71,15 +71,6 @@ class KDE_EXPORT Smb4KCustomOptions
                    RemountNever,
                    UndefinedRemount };
                   
-    /**
-     * ProtocolHint enumeration
-     */
-    enum ProtocolHint { Automatic,
-                        RAP,
-                        RPC,
-                        ADS,
-                        UndefinedProtocolHint };
-
 #if defined(Q_OS_LINUX)
     /**
      * The SecurityMode enumeration
@@ -211,7 +202,7 @@ class KDE_EXPORT Smb4KCustomOptions
      * 
      * @param url             The URL
      */
-    void setURL(const KUrl &url);
+    void setURL(const QUrl &url);
     
     /**
      * Sets the UNC/URL of the network item
@@ -225,7 +216,7 @@ class KDE_EXPORT Smb4KCustomOptions
      * 
      * @returns the URL
      */
-    KUrl url() const;
+    QUrl url() const;
 
     /**
      * Returns the UNC in the form //HOST/Share.
@@ -309,6 +300,7 @@ class KDE_EXPORT Smb4KCustomOptions
      * @returns the security mode
      */
     SecurityMode securityMode() const;
+
     /**
      * Set the write access for either a single share or all shares of a host. 
      * 
@@ -324,20 +316,6 @@ class KDE_EXPORT Smb4KCustomOptions
     WriteAccess writeAccess() const;
 #endif
 
-    /**
-     * Set the protocol hint for this network item.
-     * 
-     * @param protocol        The protocol hint
-     */
-    void setProtocolHint(ProtocolHint protocol);
-    
-    /**
-     * Returns the protocol hint for this item.
-     * 
-     * @returns the protocol hint
-     */
-    ProtocolHint protocolHint() const;
-    
     /**
      * Sets the useage of Kerberos for this network item.
      * 
@@ -353,48 +331,28 @@ class KDE_EXPORT Smb4KCustomOptions
     Kerberos useKerberos() const;
     
     /**
-     * Set the user id you want to use.
-     * 
-     * @param uid               The user id
+     * Set the user who owns the share.
+     * @param user    The user
      */
-    void setUID(K_UID uid);
+    void setUser(const KUser &user);
     
     /**
-     * Returns the user id that is to be used.
-     * 
-     * @returns the user id
+     * Returns the user who owns the share.
+     * @returns the user
      */
-    K_UID uid() const;
+    KUser user() const;
     
     /**
-     * This function returns the name of the owner as defined by the given
-     * UID.
-     * 
-     * @returns the owner's name
+     * Set the group that owns the share.
+     * @param group   The group
      */
-    QString owner() const; 
+    void setGroup(const KUserGroup &group);
     
     /**
-     * Set the group id you want to use.
-     * 
-     * @param gid               The group id
+     * Returns the group that owns the share.
+     * @returns the group
      */
-    void setGID(K_GID gid);
-    
-    /**
-     * Returns the group id that is to be used.
-     * 
-     * @returns the group id
-     */
-    K_GID gid() const;
-    
-    /**
-     * This function returns the name of the group as defined by the given
-     * GID.
-     * 
-     * @returns the owner's name
-     */
-    QString group() const;
+    KUserGroup group() const;
     
     /**
      * This function sets the MAC address of a host. In case the options 
