@@ -1,8 +1,8 @@
 /***************************************************************************
-    smb4kcustomoptionsmanager - Manage custom options
+    Manage custom options
                              -------------------
     begin                : Fr 29 Apr 2011
-    copyright            : (C) 2011-2015 by Alexander Reinholdt
+    copyright            : (C) 2011-2016 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -45,31 +45,37 @@
 #endif
 
 // Qt includes
-#include <QtCore/QXmlStreamReader>
-#include <QtCore/QXmlStreamWriter>
-#include <QtCore/QDebug>
-#include <QtCore/QCoreApplication>
-#include <QtCore/QPointer>
+#include <QXmlStreamReader>
+#include <QXmlStreamWriter>
+#include <QDebug>
+#include <QCoreApplication>
+#include <QPointer>
+#include <QStandardPaths>
 
 // KDE includes
-#include <kglobal.h>
-#include <kstandarddirs.h>
-#include <klocale.h>
+#define TRANSLATION_DOMAIN "smb4k-core"
+#include <KI18n/KLocalizedString>
 
 using namespace Smb4KGlobal;
 
-K_GLOBAL_STATIC(Smb4KCustomOptionsManagerStatic, p);
+Q_GLOBAL_STATIC(Smb4KCustomOptionsManagerStatic, p);
 
 
 Smb4KCustomOptionsManager::Smb4KCustomOptionsManager(QObject *parent)
 : QObject(parent), d(new Smb4KCustomOptionsManagerPrivate)
 {
-  // We need the directory.
-  QString dir = KGlobal::dirs()->locateLocal("data", "smb4k", KGlobal::mainComponent());
-
-  if (!KGlobal::dirs()->exists(dir))
+  // First we need the directory.
+  QString path = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
+  
+  QDir dir;
+  
+  if (!dir.exists(path))
   {
-    KGlobal::dirs()->makeDir(dir);
+    dir.mkpath(path);
+  }
+  else
+  {
+    // Do nothing
   }
   
   readCustomOptions(&d->options, false);
@@ -138,7 +144,7 @@ void Smb4KCustomOptionsManager::removeRemount(Smb4KShare *share, bool force)
   
   if (share)
   {
-    Smb4KCustomOptions *options = NULL;
+    Smb4KCustomOptions *options = 0;
     
     if ((options = findOptions(share, true)))
     {
@@ -226,7 +232,7 @@ Smb4KCustomOptions *Smb4KCustomOptionsManager::findOptions(Smb4KBasicNetworkItem
 {
   Q_ASSERT(networkItem);
   
-  Smb4KCustomOptions *options = NULL;
+  Smb4KCustomOptions *options = 0;
   
   if (networkItem)
   {
@@ -327,16 +333,16 @@ Smb4KCustomOptions *Smb4KCustomOptionsManager::findOptions(Smb4KBasicNetworkItem
 }
 
 
-Smb4KCustomOptions* Smb4KCustomOptionsManager::findOptions(const KUrl &url)
+Smb4KCustomOptions* Smb4KCustomOptionsManager::findOptions(const QUrl &url)
 {
-  Smb4KCustomOptions *options = NULL;
+  Smb4KCustomOptions *options = 0;
   
-  if (url.isValid() && QString::compare(url.protocol(), "smb") == 0)
+  if (url.isValid() && QString::compare(url.scheme(), "smb") == 0)
   {
     for (int i = 0; i < d->options.size(); ++i)
     {
       if (QString::compare(d->options.at(i)->url().host(), url.host(), Qt::CaseInsensitive) == 0 &&
-           QString::compare(d->options.at(i)->url().path(), url.path(), Qt::CaseInsensitive) == 0)
+          QString::compare(d->options.at(i)->url().path(), url.path(), Qt::CaseInsensitive) == 0)
       {
         options = d->options[i];
         break;
@@ -359,7 +365,7 @@ Smb4KCustomOptions* Smb4KCustomOptionsManager::findOptions(const KUrl &url)
 void Smb4KCustomOptionsManager::readCustomOptions(QList<Smb4KCustomOptions *> *optionsList, bool allOptions)
 {
   // Locate the XML file.
-  QFile xmlFile(KGlobal::dirs()->locateLocal("data", "smb4k/custom_options.xml", KGlobal::mainComponent()));
+  QFile xmlFile(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation)+QDir::separator()+"custom_options.xml");
 
   if (xmlFile.open(QIODevice::ReadOnly | QIODevice::Text))
   {
@@ -449,31 +455,6 @@ void Smb4KCustomOptionsManager::readCustomOptions(QList<Smb4KCustomOptions *> *o
                         {
                           options->setSMBPort(xmlReader.readElementText().toInt());
                         }
-                        else if (xmlReader.name() == "protocol")
-                        {
-                          QString protocol = xmlReader.readElementText();
-  
-                          if (QString::compare(protocol, "auto") == 0)
-                          {
-                            options->setProtocolHint(Smb4KCustomOptions::Automatic);
-                          }
-                          else if (QString::compare(protocol, "rpc") == 0)
-                          {
-                            options->setProtocolHint(Smb4KCustomOptions::RPC);
-                          }
-                          else if (QString::compare(protocol, "rap") == 0)
-                          {
-                            options->setProtocolHint(Smb4KCustomOptions::RAP);
-                          }
-                          else if (QString::compare(protocol, "ads") == 0)
-                          {
-                            options->setProtocolHint(Smb4KCustomOptions::ADS);
-                          }
-                          else
-                          {
-                            options->setProtocolHint(Smb4KCustomOptions::UndefinedProtocolHint);
-                          }
-                        }
 #if defined(Q_OS_LINUX)
                         else if (xmlReader.name() == "filesystem_port")
                         {
@@ -561,11 +542,11 @@ void Smb4KCustomOptionsManager::readCustomOptions(QList<Smb4KCustomOptions *> *o
                         }
                         else if (xmlReader.name() == "uid")
                         {
-                          options->setUID((K_UID)xmlReader.readElementText().toInt());
+                          options->setUser(KUser((K_UID)xmlReader.readElementText().toInt()));
                         }
                         else if (xmlReader.name() == "gid")
                         {
-                          options->setGID((K_GID)xmlReader.readElementText().toInt());
+                          options->setGroup(KUserGroup((K_GID)xmlReader.readElementText().toInt()));
                         }
                         else if (xmlReader.name() == "mac_address")
                         {
@@ -697,7 +678,7 @@ void Smb4KCustomOptionsManager::writeCustomOptions(const QList<Smb4KCustomOption
     allOptions << new Smb4KCustomOptions(*list[i]);
   }
   
-  QFile xmlFile(KGlobal::dirs()->locateLocal("data", "smb4k/custom_options.xml", KGlobal::mainComponent()));
+  QFile xmlFile(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation)+QDir::separator()+"custom_options.xml");
 
   if (!allOptions.isEmpty())
   {
@@ -843,7 +824,7 @@ void Smb4KCustomOptionsManager::openCustomOptionsDialog(Smb4KBasicNetworkItem *i
 {
   Q_ASSERT(item);
   
-  Smb4KCustomOptions *options = NULL;
+  Smb4KCustomOptions *options = 0;
   bool delete_options = false;
   
   if (item)
@@ -946,7 +927,7 @@ void Smb4KCustomOptionsManager::openCustomOptionsDialog(Smb4KBasicNetworkItem *i
     
     QPointer<Smb4KCustomOptionsDialog> dlg = new Smb4KCustomOptionsDialog(options, parent);
       
-    if (dlg->exec() == KDialog::Accepted)
+    if (dlg->exec() == QDialog::Accepted)
     {
       if (hasCustomOptions(options))
       {
@@ -996,7 +977,7 @@ void Smb4KCustomOptionsManager::addCustomOptions(Smb4KCustomOptions *options)
     if (known_options)
     {
       // Remove the known options from the list and add the ones that
-      // were passed. We can do this, because findOptions(KUrl) returns
+      // were passed. We can do this, because findOptions(QUrl) returns
       // the exact match.
       int index = d->options.indexOf(known_options);
       
@@ -1044,9 +1025,8 @@ void Smb4KCustomOptionsManager::addCustomOptions(Smb4KCustomOptions *options)
           d->options[i]->setSecurityMode(o->securityMode());
           d->options[i]->setWriteAccess(o->writeAccess());
 #endif
-          d->options[i]->setProtocolHint(o->protocolHint());
-          d->options[i]->setUID(o->uid());
-          d->options[i]->setGID(o->gid());
+          d->options[i]->setUser(o->user());
+          d->options[i]->setGroup(o->group());
           d->options[i]->setUseKerberos(o->useKerberos());
           d->options[i]->setMACAddress(o->macAddress());
           d->options[i]->setWOLSendBeforeNetworkScan(o->wolSendBeforeNetworkScan());
@@ -1202,35 +1182,6 @@ bool Smb4KCustomOptionsManager::hasCustomOptions(Smb4KCustomOptions *options)
       }
     }
 
-    switch (Smb4KSettings::protocolHint())
-    {
-      case Smb4KSettings::EnumProtocolHint::Automatic:
-      {
-        default_options.setProtocolHint(Smb4KCustomOptions::Automatic);
-        break;
-      }
-      case Smb4KSettings::EnumProtocolHint::RPC:
-      {
-        default_options.setProtocolHint(Smb4KCustomOptions::RPC);
-        break;
-      }
-      case Smb4KSettings::EnumProtocolHint::RAP:
-      {
-        default_options.setProtocolHint(Smb4KCustomOptions::RAP);
-        break;
-      }
-      case Smb4KSettings::EnumProtocolHint::ADS:
-      {
-        default_options.setProtocolHint(Smb4KCustomOptions::ADS);
-        break;
-      }
-      default:
-      {
-        default_options.setProtocolHint(Smb4KCustomOptions::UndefinedProtocolHint);
-        break;
-      }
-    }
-
     if (Smb4KSettings::useKerberos())
     {
       default_options.setUseKerberos(Smb4KCustomOptions::UseKerberos);
@@ -1240,8 +1191,8 @@ bool Smb4KCustomOptionsManager::hasCustomOptions(Smb4KCustomOptions *options)
       default_options.setUseKerberos(Smb4KCustomOptions::NoKerberos);
     }
 
-    default_options.setUID((K_UID)Smb4KMountSettings::userID().toInt());
-    default_options.setGID((K_GID)Smb4KMountSettings::groupID().toInt());
+    default_options.setUser(KUser((K_UID)Smb4KMountSettings::userID().toInt()));
+    default_options.setGroup(KUserGroup((K_GID)Smb4KMountSettings::groupID().toInt()));
 
     // NOTE: WOL features and remounting do not have default values.
     //
@@ -1302,17 +1253,6 @@ bool Smb4KCustomOptionsManager::hasCustomOptions(Smb4KCustomOptions *options)
       // Do nothing
     }
 
-    // Protocol hint
-    if (empty_options.protocolHint() != options->protocolHint() &&
-        default_options.protocolHint() != options->protocolHint())
-    {
-      return true;
-    }
-    else
-    {
-      // Do nothing
-    }
-
     // Kerberos
     if (empty_options.useKerberos() != options->useKerberos() &&
         default_options.useKerberos() != options->useKerberos())
@@ -1324,9 +1264,9 @@ bool Smb4KCustomOptionsManager::hasCustomOptions(Smb4KCustomOptions *options)
       // Do nothing
     }
 
-    // UID
-    if (empty_options.uid() != options->uid() &&
-        default_options.uid() != options->uid())
+    // User / UID
+    if (empty_options.user().userId() != options->user().userId() &&
+        default_options.user().userId() != options->user().userId())
     {
       return true;
     }
@@ -1335,9 +1275,9 @@ bool Smb4KCustomOptionsManager::hasCustomOptions(Smb4KCustomOptions *options)
       // Do nothing
     }
 
-    // GID
-    if (empty_options.gid() != options->gid() &&
-        default_options.gid() != options->gid())
+    // Group / GID
+    if (empty_options.group().groupId() != options->group().groupId() &&
+        default_options.group().groupId() != options->group().groupId())
     {
       return true;
     }
@@ -1405,35 +1345,6 @@ bool Smb4KCustomOptionsManager::hasCustomOptions(Smb4KCustomOptions *options)
     // Set up the default options
     default_options.setSMBPort(Smb4KSettings::remoteSMBPort());
 
-    switch (Smb4KSettings::protocolHint())
-    {
-      case Smb4KSettings::EnumProtocolHint::Automatic:
-      {
-        default_options.setProtocolHint(Smb4KCustomOptions::Automatic);
-        break;
-      }
-      case Smb4KSettings::EnumProtocolHint::RPC:
-      {
-        default_options.setProtocolHint(Smb4KCustomOptions::RPC);
-        break;
-      }
-      case Smb4KSettings::EnumProtocolHint::RAP:
-      {
-        default_options.setProtocolHint(Smb4KCustomOptions::RAP);
-        break;
-      }
-      case Smb4KSettings::EnumProtocolHint::ADS:
-      {
-        default_options.setProtocolHint(Smb4KCustomOptions::ADS);
-        break;
-      }
-      default:
-      {
-        default_options.setProtocolHint(Smb4KCustomOptions::UndefinedProtocolHint);
-        break;
-      }
-    }
-
     if (Smb4KSettings::useKerberos())
     {
       default_options.setUseKerberos(Smb4KCustomOptions::UseKerberos);
@@ -1443,8 +1354,8 @@ bool Smb4KCustomOptionsManager::hasCustomOptions(Smb4KCustomOptions *options)
       default_options.setUseKerberos(Smb4KCustomOptions::NoKerberos);
     }
 
-    default_options.setUID((K_UID)Smb4KMountSettings::userID().toInt());
-    default_options.setGID((K_GID)Smb4KMountSettings::groupID().toInt());
+    default_options.setUser(KUser((K_UID)Smb4KMountSettings::userID().toInt()));
+    default_options.setGroup(KUserGroup((K_GID)Smb4KMountSettings::groupID().toInt()));
 
     // NOTE: WOL features and remounting do not have default values.
     //
@@ -1472,17 +1383,6 @@ bool Smb4KCustomOptionsManager::hasCustomOptions(Smb4KCustomOptions *options)
       // Do nothing
     }
 
-    // Protocol hint
-    if (empty_options.protocolHint() != options->protocolHint() &&
-        default_options.protocolHint() != options->protocolHint())
-    {
-      return true;
-    }
-    else
-    {
-      // Do nothing
-    }
-
     // Kerberos
     if (empty_options.useKerberos() != options->useKerberos() &&
         default_options.useKerberos() != options->useKerberos())
@@ -1494,9 +1394,9 @@ bool Smb4KCustomOptionsManager::hasCustomOptions(Smb4KCustomOptions *options)
       // Do nothing
     }
 
-    // UID
-    if (empty_options.uid() != options->uid() &&
-        default_options.uid() != options->uid())
+    // User / UID
+    if (empty_options.user().userId() != options->user().userId() &&
+        default_options.user().userId() != options->user().userId())
     {
       return true;
     }
@@ -1505,9 +1405,9 @@ bool Smb4KCustomOptionsManager::hasCustomOptions(Smb4KCustomOptions *options)
       // Do nothing
     }
 
-    // GID
-    if (empty_options.gid() != options->gid() &&
-        default_options.gid() != options->gid())
+    // Group / GID
+    if (empty_options.group().groupId() != options->group().groupId() &&
+        default_options.group().groupId() != options->group().groupId())
     {
       return true;
     }
@@ -1575,35 +1475,6 @@ bool Smb4KCustomOptionsManager::hasCustomOptions(Smb4KCustomOptions *options)
     // Set up the default options
     default_options.setSMBPort(Smb4KSettings::remoteSMBPort());
 
-    switch (Smb4KSettings::protocolHint())
-    {
-      case Smb4KSettings::EnumProtocolHint::Automatic:
-      {
-        default_options.setProtocolHint(Smb4KCustomOptions::Automatic);
-        break;
-      }
-      case Smb4KSettings::EnumProtocolHint::RPC:
-      {
-        default_options.setProtocolHint(Smb4KCustomOptions::RPC);
-        break;
-      }
-      case Smb4KSettings::EnumProtocolHint::RAP:
-      {
-        default_options.setProtocolHint(Smb4KCustomOptions::RAP);
-        break;
-      }
-      case Smb4KSettings::EnumProtocolHint::ADS:
-      {
-        default_options.setProtocolHint(Smb4KCustomOptions::ADS);
-        break;
-      }
-      default:
-      {
-        default_options.setProtocolHint(Smb4KCustomOptions::UndefinedProtocolHint);
-        break;
-      }
-    }
-
     if (Smb4KSettings::useKerberos())
     {
       default_options.setUseKerberos(Smb4KCustomOptions::UseKerberos);
@@ -1639,17 +1510,6 @@ bool Smb4KCustomOptionsManager::hasCustomOptions(Smb4KCustomOptions *options)
       // Do nothing
     }
 
-    // Protocol hint
-    if (empty_options.protocolHint() != options->protocolHint() &&
-        default_options.protocolHint() != options->protocolHint())
-    {
-      return true;
-    }
-    else
-    {
-      // Do nothing
-    }
-
     // Kerberos
     if (empty_options.useKerberos() != options->useKerberos() &&
         default_options.useKerberos() != options->useKerberos())
@@ -1819,5 +1679,3 @@ void Smb4KCustomOptionsManager::slotActiveProfileChanged(const QString& /*active
   readCustomOptions(&d->options, false);
 }
 
-
-#include "smb4kcustomoptionsmanager.moc"
