@@ -1,9 +1,8 @@
 /***************************************************************************
-    smb4kdeclarative - This class provides helper classes for 
-    Smb4KDeclarative
+    This class provides helper classes for Smb4KDeclarative
                              -------------------
     begin                : Mo 02 Sep 2013
-    copyright            : (C) 2013-2014 by Alexander Reinholdt
+    copyright            : (C) 2013-2016 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
