@@ -1,8 +1,8 @@
 /***************************************************************************
-    smb4kglobal  -  This is the global namespace for Smb4K.
+    This is the global namespace for Smb4K.
                              -------------------
     begin                : Sa Apr 2 2005
-    copyright            : (C) 2005-2014 by Alexander Reinholdt
+    copyright            : (C) 2005-2016 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -39,21 +39,17 @@
 #include "smb4ksearch.h"
 
 // Qt includes
-#include <QtCore/QMutex>
+#include <QMutex>
+#include <QUrl>
+#include <QStandardPaths>
+#include <QDebug>
 
 // KDE includes
-#include <kdebug.h>
-#include <kurl.h>
-#include <krun.h>
-#include <kglobal.h>
-#include <kstandarddirs.h>
-#include <kshell.h>
-#include <KGlobal>
+#include <KCoreAddons/KShell>
+#include <KIOWidgets/KRun>
 
-static const KCatalogLoader catalogLoader( QLatin1String("smb4k-core") );
-
-K_GLOBAL_STATIC( Smb4KGlobalPrivate, p );
-QMutex mutex( QMutex::Recursive /* needed to avoid dead-locks */ );
+Q_GLOBAL_STATIC(Smb4KGlobalPrivate, p);
+QMutex mutex(QMutex::Recursive /* needed to avoid dead-locks */);
 
 
 const QEvent::Type Smb4KGlobal::Smb4KEvent::LoadSettings =        (QEvent::Type)QEvent::registerEventType();
@@ -63,7 +59,7 @@ const QEvent::Type Smb4KGlobal::Smb4KEvent::AddBookmark =         (QEvent::Type)
 const QEvent::Type Smb4KGlobal::Smb4KEvent::MountOrUnmountShare = (QEvent::Type)QEvent::registerEventType();
 
 
-Smb4KGlobal::Smb4KEvent::Smb4KEvent( QEvent::Type type ): QEvent( type )
+Smb4KGlobal::Smb4KEvent::Smb4KEvent(QEvent::Type type): QEvent(type)
 {
 }
 
@@ -138,23 +134,22 @@ const QList<Smb4KWorkgroup *> &Smb4KGlobal::workgroupsList()
 }
 
 
-Smb4KWorkgroup *Smb4KGlobal::findWorkgroup( const QString &name )
+Smb4KWorkgroup *Smb4KGlobal::findWorkgroup(const QString &name)
 {
-  Smb4KWorkgroup *workgroup = NULL;
+  Smb4KWorkgroup *workgroup = 0;
 
   mutex.lock();
-
-  for ( int i = 0; i < p->workgroupsList.size(); ++i )
+  
+  for (Smb4KWorkgroup *w : p->workgroupsList)
   {
-    if ( QString::compare( p->workgroupsList.at( i )->workgroupName(),
-         name, Qt::CaseInsensitive ) == 0 )
+    if (QString::compare(w->workgroupName(), name, Qt::CaseInsensitive) == 0)
     {
-      workgroup = p->workgroupsList.at( i );
+      workgroup = w;
       break;
     }
     else
     {
-      continue;
+      // Do nothing
     }
   }
 
@@ -164,17 +159,17 @@ Smb4KWorkgroup *Smb4KGlobal::findWorkgroup( const QString &name )
 }
 
 
-bool Smb4KGlobal::addWorkgroup( Smb4KWorkgroup *workgroup )
+bool Smb4KGlobal::addWorkgroup(Smb4KWorkgroup *workgroup)
 {
-  Q_ASSERT( workgroup );
+  Q_ASSERT(workgroup);
 
   bool added = false;
 
   mutex.lock();
 
-  if ( !findWorkgroup( workgroup->workgroupName() ) )
+  if (!findWorkgroup(workgroup->workgroupName()))
   {
-    p->workgroupsList.append( workgroup );
+    p->workgroupsList.append(workgroup);
     added = true;
   }
   else
@@ -188,34 +183,34 @@ bool Smb4KGlobal::addWorkgroup( Smb4KWorkgroup *workgroup )
 }
 
 
-bool Smb4KGlobal::removeWorkgroup( Smb4KWorkgroup *workgroup )
+bool Smb4KGlobal::removeWorkgroup(Smb4KWorkgroup *workgroup)
 {
-  Q_ASSERT( workgroup );
+  Q_ASSERT(workgroup);
 
   bool removed = false;
 
   mutex.lock();
 
-  int index = p->workgroupsList.indexOf( workgroup );
+  int index = p->workgroupsList.indexOf(workgroup);
 
-  if ( index != -1 )
+  if (index != -1)
   {
     // The workgroup was found. Remove it.
-    delete p->workgroupsList.takeAt( index );
+    delete p->workgroupsList.takeAt(index);
     removed = true;
   }
   else
   {
     // Try harder to find the workgroup.
-    Smb4KWorkgroup *wg = findWorkgroup( workgroup->workgroupName() );
+    Smb4KWorkgroup *wg = findWorkgroup(workgroup->workgroupName());
 
-    if ( wg )
+    if (wg)
     {
-      index = p->workgroupsList.indexOf( wg );
+      index = p->workgroupsList.indexOf(wg);
 
-      if ( index != -1 )
+      if (index != -1)
       {
-        delete p->workgroupsList.takeAt( index );
+        delete p->workgroupsList.takeAt(index);
         removed = true;
       }
       else
@@ -241,7 +236,7 @@ void Smb4KGlobal::clearWorkgroupsList()
 {
   mutex.lock();
 
-  while ( !p->workgroupsList.isEmpty() )
+  while (!p->workgroupsList.isEmpty())
   {
     delete p->workgroupsList.takeFirst();
   }
@@ -256,26 +251,23 @@ const QList<Smb4KHost *> &Smb4KGlobal::hostsList()
 }
 
 
-Smb4KHost *Smb4KGlobal::findHost( const QString &name, const QString &workgroup )
+Smb4KHost *Smb4KGlobal::findHost(const QString &name, const QString &workgroup)
 {
-  Smb4KHost *host = NULL;
+  Smb4KHost *host = 0;
 
   mutex.lock();
-
-  for ( int i = 0; i < p->hostsList.size(); ++i )
+  
+  for (Smb4KHost *h : p->hostsList)
   {
-    if ( (workgroup.isEmpty() ||
-         QString::compare( p->hostsList.at( i )->workgroupName(),
-         workgroup, Qt::CaseInsensitive ) == 0) &&
-         QString::compare( p->hostsList.at( i )->hostName(), name,
-         Qt::CaseInsensitive ) == 0 )
+    if ((workgroup.isEmpty() || QString::compare(h->workgroupName(), workgroup, Qt::CaseInsensitive) == 0) &&
+        QString::compare(h->hostName(), name, Qt::CaseInsensitive) == 0)
     {
-      host = p->hostsList.at( i );
+      host = h;
       break;
     }
     else
     {
-      continue;
+      // Do nothing
     }
   }
 
@@ -285,17 +277,17 @@ Smb4KHost *Smb4KGlobal::findHost( const QString &name, const QString &workgroup
 }
 
 
-bool Smb4KGlobal::addHost( Smb4KHost *host )
+bool Smb4KGlobal::addHost(Smb4KHost *host)
 {
-  Q_ASSERT( host );
+  Q_ASSERT(host);
 
   bool added = false;
 
   mutex.lock();
 
-  if ( !findHost( host->hostName(), host->workgroupName() ) )
+  if (!findHost(host->hostName(), host->workgroupName()))
   {
-    p->hostsList.append( host );
+    p->hostsList.append(host);
     added = true;
   }
   else
@@ -309,34 +301,34 @@ bool Smb4KGlobal::addHost( Smb4KHost *host )
 }
 
 
-bool Smb4KGlobal::removeHost( Smb4KHost *host )
+bool Smb4KGlobal::removeHost(Smb4KHost *host)
 {
-  Q_ASSERT( host );
+  Q_ASSERT(host);
 
   bool removed = false;
 
   mutex.lock();
 
-  int index = p->hostsList.indexOf( host );
+  int index = p->hostsList.indexOf(host);
 
-  if ( index != -1 )
+  if (index != -1)
   {
     // The host was found. Remove it.
-    delete p->hostsList.takeAt( index );
+    delete p->hostsList.takeAt(index);
     removed = true;
   }
   else
   {
     // Try harder to find the host.
-    Smb4KHost *h = findHost( host->hostName(), host->workgroupName() );
+    Smb4KHost *h = findHost(host->hostName(), host->workgroupName());
 
-    if ( h )
+    if (h)
     {
-      index = p->hostsList.indexOf( h );
+      index = p->hostsList.indexOf(h);
 
-      if ( index != -1 )
+      if (index != -1)
       {
-        delete p->hostsList.takeAt( index );
+        delete p->hostsList.takeAt(index);
         removed = true;
       }
       else
@@ -362,7 +354,7 @@ void Smb4KGlobal::clearHostsList()
 {
   mutex.lock();
 
-  while ( !p->hostsList.isEmpty() )
+  while (!p->hostsList.isEmpty())
   {
     delete p->hostsList.takeFirst();
   }
@@ -371,22 +363,21 @@ void Smb4KGlobal::clearHostsList()
 }
 
 
-QList<Smb4KHost *> Smb4KGlobal::workgroupMembers( Smb4KWorkgroup *workgroup )
+QList<Smb4KHost *> Smb4KGlobal::workgroupMembers(Smb4KWorkgroup *workgroup)
 {
   QList<Smb4KHost *> hosts;
 
   mutex.lock();
-
-  for ( int i = 0; i < p->hostsList.size(); ++i )
+  
+  for (Smb4KHost *h : p->hostsList)
   {
-    if ( QString::compare( p->hostsList.at( i )->workgroupName(), workgroup->workgroupName(), Qt::CaseInsensitive ) == 0 )
+    if (QString::compare(h->workgroupName(), workgroup->workgroupName(), Qt::CaseInsensitive) == 0)
     {
-      hosts += p->hostsList.at( i );
-      continue;
+      hosts += h;
     }
     else
     {
-      continue;
+      // Do nothing
     }
   }
 
@@ -402,45 +393,52 @@ const QList<Smb4KShare *> &Smb4KGlobal::sharesList()
 }
 
 
-Smb4KShare *Smb4KGlobal::findShare( const QString &name, const QString &host, const QString &workgroup )
+Smb4KShare *Smb4KGlobal::findShare(const QString& unc, const QString& workgroup)
 {
-  Smb4KShare *share = NULL;
-
+  Smb4KShare *share = 0;
+  
   mutex.lock();
 
-  for ( int i = 0; i < p->sharesList.size(); ++i )
+  for (Smb4KShare *s : p->sharesList)
   {
-    if ( (workgroup.isEmpty() ||
-         QString::compare( p->sharesList.at( i )->workgroupName(), workgroup, Qt::CaseInsensitive ) == 0) &&
-         QString::compare( p->sharesList.at( i )->hostName(), host, Qt::CaseInsensitive ) == 0 &&
-         QString::compare( p->sharesList.at( i )->shareName(), name, Qt::CaseInsensitive ) == 0 )
+    if (QString::compare(s->unc(), unc, Qt::CaseInsensitive) == 0 &&
+        (workgroup.isEmpty() || QString::compare(s->workgroupName(), workgroup, Qt::CaseInsensitive) == 0))
     {
-      share = p->sharesList.at( i );
+      share = s;
+      break;
     }
     else
     {
-      continue;
+      // Do nothing
     }
   }
-
+  
   mutex.unlock();
-
+  
   return share;
 }
 
 
-bool Smb4KGlobal::addShare( Smb4KShare *share )
+
+bool Smb4KGlobal::addShare(Smb4KShare *share)
 {
-  Q_ASSERT( share );
+  Q_ASSERT(share);
 
   bool added = false;
-
-  mutex.lock();
-
-  if ( !findShare( share->shareName(), share->hostName(), share->workgroupName() ) )
+  
+  if (share)
   {
-    p->sharesList.append( share );
-    added = true;
+    mutex.lock();
+
+    if (!findShare(share->unc(), share->workgroupName()))
+    {
+      p->sharesList.append(share);
+      added = true;
+    }
+    else
+    {
+      // Do nothing
+    }
   }
   else
   {
@@ -453,50 +451,57 @@ bool Smb4KGlobal::addShare( Smb4KShare *share )
 }
 
 
-bool Smb4KGlobal::removeShare( Smb4KShare *share )
+bool Smb4KGlobal::removeShare(Smb4KShare *share)
 {
-  Q_ASSERT( share );
+  Q_ASSERT(share);
 
   bool removed = false;
-
-  mutex.lock();
-
-  int index = p->sharesList.indexOf( share );
-
-  if ( index != -1 )
+  
+  if (share)
   {
-    // The share was found. Remove it.
-    delete p->sharesList.takeAt( index );
-    removed = true;
-  }
-  else
-  {
-    // Try harder to find the share.
-    Smb4KShare *s = findShare( share->shareName(), share->hostName(), share->workgroupName() );
+    mutex.lock();
 
-    if ( s )
+    int index = p->sharesList.indexOf(share);
+
+    if (index != -1)
     {
-      index = p->sharesList.indexOf( s );
+      // The share was found. Remove it.
+      delete p->sharesList.takeAt(index);
+      removed = true;
+    }
+    else
+    {
+      // Try harder to find the share.
+      Smb4KShare *s = findShare(share->unc(), share->workgroupName());
 
-      if ( index != -1 )
+      if (s)
       {
-        delete p->sharesList.takeAt( index );
-        removed = true;
+        index = p->sharesList.indexOf(s);
+
+        if (index != -1)
+        {
+          delete p->sharesList.takeAt(index);
+          removed = true;
+        }
+        else
+        {
+          // Do nothing
+        }
       }
       else
       {
         // Do nothing
       }
-    }
-    else
-    {
-      // Do nothing
+
+      delete share;
     }
 
-    delete share;
+    mutex.unlock();
+  }
+  else
+  {
+    // Do nothing
   }
-
-  mutex.unlock();
 
   return removed;
 }
@@ -506,7 +511,7 @@ void Smb4KGlobal::clearSharesList()
 {
   mutex.lock();
 
-  while ( !p->sharesList.isEmpty() )
+  while (!p->sharesList.isEmpty())
   {
     delete p->sharesList.takeFirst();
   }
@@ -515,23 +520,22 @@ void Smb4KGlobal::clearSharesList()
 }
 
 
-QList<Smb4KShare *> Smb4KGlobal::sharedResources( Smb4KHost *host )
+QList<Smb4KShare *> Smb4KGlobal::sharedResources(Smb4KHost *host)
 {
   QList<Smb4KShare *> shares;
 
   mutex.lock();
-
-  for ( int i = 0; i < p->sharesList.size(); ++i )
+  
+  for (Smb4KShare *s : p->sharesList)
   {
-    if ( QString::compare( p->sharesList.at( i )->hostName(), host->hostName(), Qt::CaseInsensitive ) == 0 &&
-         QString::compare( p->sharesList.at( i )->workgroupName(), host->workgroupName(), Qt::CaseInsensitive ) == 0 )
+    if (QString::compare(s->hostName(), host->hostName(), Qt::CaseInsensitive) == 0 &&
+        QString::compare(s->workgroupName(), host->workgroupName(), Qt::CaseInsensitive) == 0)
     {
-      shares += p->sharesList.at( i );
-      continue;
+      shares += s;
     }
     else
     {
-      continue;
+      // Do nothing
     }
   }
 
@@ -547,25 +551,25 @@ const QList<Smb4KShare *> &Smb4KGlobal::mountedSharesList()
 }
 
 
-Smb4KShare* Smb4KGlobal::findShareByPath( const QString &path )
+Smb4KShare* Smb4KGlobal::findShareByPath(const QString &path)
 {
-  Smb4KShare *share = NULL;
+  Smb4KShare *share = 0;
 
   mutex.lock();
 
-  if ( !path.isEmpty() && !p->mountedSharesList.isEmpty() )
+  if (!path.isEmpty() && !p->mountedSharesList.isEmpty())
   {
-    for ( int i = 0; i < p->mountedSharesList.size(); ++i )
+    for (Smb4KShare *s : p->mountedSharesList)
     {
-      if ( QString::compare( path, p->mountedSharesList.at( i )->path(), Qt::CaseInsensitive ) == 0 ||
-           QString::compare( path, p->mountedSharesList.at( i )->canonicalPath(), Qt::CaseInsensitive ) == 0 )
+      if (QString::compare(s->path(), path, Qt::CaseInsensitive) == 0 ||
+          QString::compare(s->canonicalPath(), path, Qt::CaseInsensitive) == 0)
       {
-        share = p->mountedSharesList.at( i );
+        share = s;
         break;
       }
       else
       {
-        continue;
+        // Do nothing
       }
     }
   }
@@ -580,25 +584,23 @@ Smb4KShare* Smb4KGlobal::findShareByPath( const QString &path )
 }
 
 
-QList<Smb4KShare *> Smb4KGlobal::findShareByUNC( const QString &unc )
+QList<Smb4KShare *> Smb4KGlobal::findShareByUNC(const QString &unc)
 {
-  QList<Smb4KShare *> list;
+  QList<Smb4KShare *> shares;
 
   mutex.lock();
 
-  if ( !unc.isEmpty() && !p->mountedSharesList.isEmpty() )
+  if (!unc.isEmpty() && !p->mountedSharesList.isEmpty())
   {
-    for ( int i = 0; i < p->mountedSharesList.size(); ++i )
+    for (Smb4KShare *s : p->mountedSharesList)
     {
-      if ( QString::compare( unc, p->mountedSharesList.at( i )->unc(), Qt::CaseInsensitive ) == 0 ||
-           QString::compare( QString( unc ).replace( ' ', '_' ), p->mountedSharesList.at( i )->unc(), Qt::CaseInsensitive ) == 0  )
+      if (QString::compare(s->unc(), unc, Qt::CaseInsensitive) == 0)
       {
-        list.append( p->mountedSharesList.at( i ) );
-        continue;
+        shares += s;
       }
       else
       {
-        continue;
+        // Do nothing
       }
     }
   }
@@ -609,138 +611,62 @@ QList<Smb4KShare *> Smb4KGlobal::findShareByUNC( const QString &unc )
 
   mutex.unlock();
 
-  return list;
+  return shares;
 }
 
 
 QList<Smb4KShare*> Smb4KGlobal::findInaccessibleShares()
 {
-  QList<Smb4KShare *> inaccessible_shares;
+  QList<Smb4KShare *> inaccessibleShares;
 
   mutex.lock();
-
-  for ( int i = 0; i < p->mountedSharesList.size(); ++i )
+  
+  for (Smb4KShare *s : p->mountedSharesList)
   {
-    if ( p->mountedSharesList.at( i )->isInaccessible() )
+    if (s->isInaccessible())
     {
-      inaccessible_shares.append( p->mountedSharesList.at( i ) );
-
-      continue;
+      inaccessibleShares += s;
     }
     else
     {
-      continue;
+      // Do nothing
     }
   }
 
   mutex.unlock();
 
-  return inaccessible_shares;
+  return inaccessibleShares;
 }
 
 
-bool Smb4KGlobal::addMountedShare( Smb4KShare *share )
+bool Smb4KGlobal::addMountedShare(Smb4KShare *share)
 {
-  Q_ASSERT( share );
+  Q_ASSERT(share);
 
   bool added = false;
 
-  mutex.lock();
-
-  if ( !findShareByPath( share->path() ) )
+  if (share)
   {
-    p->mountedSharesList.append( share );
-    added = true;
+    mutex.lock();
 
-    p->onlyForeignShares = true;
-
-    for ( int i = 0; i < p->mountedSharesList.size(); ++i )
+    if (!findShareByPath(share->path()))
     {
-      if ( !p->mountedSharesList.at( i )->isForeign() )
+      p->mountedSharesList.append(share);
+      added = true;
+
+      p->onlyForeignShares = true;
+    
+      for (Smb4KShare *s : p->mountedSharesList)
       {
-        p->onlyForeignShares = false;
-        break;
-      }
-      else
-      {
-        continue;
-      }
-    }
-  }
-  else
-  {
-    // Do nothing
-  }
-
-  mutex.unlock();
-
-  return added;
-}
-
-
-bool Smb4KGlobal::removeMountedShare( Smb4KShare *share )
-{
-  Q_ASSERT( share );
-
-  bool removed = false;
-
-  mutex.lock();
-
-  int index = p->mountedSharesList.indexOf( share );
-
-  if ( index != -1 )
-  {
-    // The share was found. Remove it.
-    delete p->mountedSharesList.takeAt( index );
-    removed = true;
-
-    p->onlyForeignShares = true;
-
-    for ( int i = 0; i < p->mountedSharesList.size(); ++i )
-    {
-      if ( !p->mountedSharesList.at( i )->isForeign() )
-      {
-        p->onlyForeignShares = false;
-        break;
-      }
-      else
-      {
-        continue;
-      }
-    }
-  }
-  else
-  {
-    // Try harder to find the mounted share.
-    Smb4KShare *s = findShareByPath( share->path() );
-
-    if ( s )
-    {
-      index = p->mountedSharesList.indexOf( s );
-
-      if ( index != -1 )
-      {
-        delete p->mountedSharesList.takeAt( index );
-        removed = true;
-
-        p->onlyForeignShares = true;
-
-        for ( int i = 0; i < p->mountedSharesList.size(); ++i )
+        if (!s->isForeign())
         {
-          if ( !p->mountedSharesList.at( i )->isForeign() )
-          {
-            p->onlyForeignShares = false;
-            break;
-          }
-          else
-          {
-            continue;
-          }
+          p->onlyForeignShares = false;
+          break;
+        }
+        else
+        {
+          // Do nothing
         }
-      }
-      else
-      {
-        // Do nothing
       }
     }
     else
@@ -748,11 +674,99 @@ bool Smb4KGlobal::removeMountedShare( Smb4KShare *share )
       // Do nothing
     }
 
-    delete share;
+    mutex.unlock();
+  }
+  else
+  {
+    // Do nothing
   }
 
-  mutex.unlock();
+  return added;
+}
 
+
+bool Smb4KGlobal::updateMountedShare(Smb4KShare* share)
+{
+  Q_ASSERT(share);
+  
+  bool updated = false;
+  
+  if (share)
+  {
+    Smb4KShare *mountedShare = findShareByPath(share->path());
+    
+    if (mountedShare)
+    {
+      // Update share
+      mountedShare->setMountData(share);
+      updated = true;
+    }
+    else
+    {
+      // Do nothing
+    }
+  }
+  else
+  {
+    // Do nothing
+  }
+  
+  return updated;
+}
+
+
+bool Smb4KGlobal::removeMountedShare(Smb4KShare *share)
+{
+  Q_ASSERT(share);
+
+  bool removed = false;
+  
+  if (share)
+  {
+    mutex.lock();
+  
+    // Find the share by its path and remove it.
+    QMutableListIterator<Smb4KShare *> it(p->mountedSharesList);
+    
+    while (it.hasNext())
+    {
+      Smb4KShare *s = it.next();
+      
+      if (QString::compare(s->path(), share->path(), Qt::CaseInsensitive) == 0 ||
+          QString::compare(s->canonicalPath(), share->canonicalPath(), Qt::CaseInsensitive) == 0)
+      {
+        it.remove();
+        removed = true;
+        break;
+      }
+      else
+      {
+        // Do nothing
+      }
+    }
+    
+    for (Smb4KShare *s : p->mountedSharesList)
+    {
+      if (!s->isForeign())
+      {
+        p->onlyForeignShares = false;
+        break;
+      }
+      else
+      {
+        // Do nothing
+      }
+    }
+    
+    delete share;
+    
+    mutex.unlock();
+  }
+  else
+  {
+    // Do nothing
+  }
+  
   return removed;
 }
 
@@ -763,35 +777,34 @@ bool Smb4KGlobal::onlyForeignMountedShares()
 }
 
 
-void Smb4KGlobal::openShare( Smb4KShare *share, OpenWith openWith )
+void Smb4KGlobal::openShare(Smb4KShare *share, OpenWith openWith)
 {
-  if ( !share || share->isInaccessible() )
+  if (!share || share->isInaccessible())
   {
     return;
   }
 
-  switch ( openWith )
+  switch (openWith)
   {
     case FileManager:
     {
-      KUrl url;
-      url.setPath( share->canonicalPath() );
+      QUrl url = QUrl::fromLocalFile(share->canonicalPath());
 
-      (void) new KRun( url, 0, 0, true );
+      (void) new KRun(url, 0);
 
       break;
     }
     case Konsole:
     {
-      QString konsole = KGlobal::dirs()->findResource( "exe", "konsole" );
+      QString konsole = QStandardPaths::findExecutable("konsole");
 
-      if ( konsole.isEmpty() )
+      if (konsole.isEmpty())
       {
         Smb4KNotification::commandNotFound("konsole");
       }
       else
       {
-        KRun::runCommand( konsole+" --workdir "+KShell::quoteArg( share->canonicalPath() ), 0 );
+        KRun::runCommand(konsole+" --workdir "+KShell::quoteArg(share->canonicalPath()), 0);
       }
 
       break;
@@ -804,26 +817,26 @@ void Smb4KGlobal::openShare( Smb4KShare *share, OpenWith openWith )
 }
 
 
-const QMap<QString,QString> &Smb4KGlobal::globalSambaOptions( bool read )
+const QMap<QString,QString> &Smb4KGlobal::globalSambaOptions(bool read)
 {
-  return p->globalSambaOptions( read );
+  return p->globalSambaOptions(read);
 }
 
 
 const QString Smb4KGlobal::winsServer()
 {
-  QMap<QString,QString> global_opts = p->globalSambaOptions( false );
+  QMap<QString,QString> global_opts = p->globalSambaOptions(false);
   QString wins_server;
   
-  if ( global_opts.contains( "wins server" ) )
+  if (global_opts.contains("wins server"))
   {
-    wins_server = global_opts.value( "wins server" );
+    wins_server = global_opts.value("wins server");
   }
   else
   {
-    if ( global_opts.contains( "wins support" ) &&
-         (QString::compare( global_opts.value( "wins support" ), "yes", Qt::CaseInsensitive ) == 0 ||
-          QString::compare( global_opts.value( "wins support" ), "true", Qt::CaseInsensitive ) == 0) )
+    if (global_opts.contains("wins support") &&
+         (QString::compare(global_opts.value("wins support"), "yes", Qt::CaseInsensitive) == 0 ||
+          QString::compare(global_opts.value("wins support"), "true", Qt::CaseInsensitive) == 0))
     {
       wins_server = "127.0.0.1";
     }
@@ -843,7 +856,7 @@ bool Smb4KGlobal::modifyCursor()
 }
 
 
-#ifdef Q_OS_LINUX
+#if defined(Q_OS_LINUX)
 QStringList Smb4KGlobal::whitelistedMountArguments()
 {
   return p->whitelistedMountArguments;
@@ -851,3 +864,35 @@ QStringList Smb4KGlobal::whitelistedMountArguments()
 #endif
 
 
+const QString Smb4KGlobal::findMountExecutable()
+{
+  QStringList paths;
+  paths << "/bin";
+  paths << "/sbin";
+  paths << "/usr/bin";
+  paths << "/usr/sbin";
+  paths << "/usr/local/bin";
+  paths << "/usr/local/sbin";
+
+#if defined(Q_OS_LINUX)
+  return QStandardPaths::findExecutable("mount.cifs", paths);
+#elif defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
+  return QStandardPaths::findExecutable("mount_smbfs", paths);
+#else
+  return QString();
+#endif
+}
+
+
+const QString Smb4KGlobal::findUmountExecutable()
+{
+  QStringList paths;
+  paths << "/bin";
+  paths << "/sbin";
+  paths << "/usr/bin";
+  paths << "/usr/sbin";
+  paths << "/usr/local/bin";
+  paths << "/usr/local/sbin";
+
+  return QStandardPaths::findExecutable("umount", paths);
+}
