@@ -1,9 +1,8 @@
 /***************************************************************************
-    smb4kglobal_p  -  This is the private helper class of the Smb4KGlobal
-    namespace.
+    These are the private helper classes of the Smb4KGlobal namespace.
                              -------------------
     begin                : Di Jul 24 2007
-    copyright            : (C) 2007-2015 by Alexander Reinholdt
+    copyright            : (C) 2007-2016 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -34,21 +33,21 @@
 #include "smb4ksettings.h"
 
 // Qt includes
-#include <QtCore/QDir>
-#include <QtCore/QTextStream>
-#include <QtCore/QTextCodec>
-#include <QtCore/QFile>
-#include <QtCore/QCoreApplication>
-#include <QtNetwork/QHostAddress>
-#include <QtNetwork/QAbstractSocket>
-#include <QtNetwork/QHostInfo>
+#include <QDir>
+#include <QTextStream>
+#include <QTextCodec>
+#include <QFile>
+#include <QCoreApplication>
+#include <QHostAddress>
+#include <QAbstractSocket>
+#include <QHostInfo>
 
 
 Smb4KGlobalPrivate::Smb4KGlobalPrivate()
 {
   onlyForeignShares = false;
   coreInitialized = false;
-  m_samba_options_read = false;
+  m_sambaConfigMissing = false;
   
 #ifdef Q_OS_LINUX
   whitelistedMountArguments << "dynperm";
@@ -77,77 +76,67 @@ Smb4KGlobalPrivate::Smb4KGlobalPrivate()
 Smb4KGlobalPrivate::~Smb4KGlobalPrivate()
 {
   // Clear the workgroup list.
-  while ( !workgroupsList.isEmpty() )
+  while (!workgroupsList.isEmpty())
   {
     delete workgroupsList.takeFirst();
   }
 
   // Clear the host list.
-  while ( !hostsList.isEmpty() )
+  while (!hostsList.isEmpty())
   {
     delete hostsList.takeFirst();
   }
 
   // Clear the list of mounted shares.
-  while ( !mountedSharesList.isEmpty() )
+  while (!mountedSharesList.isEmpty())
   {
     delete mountedSharesList.takeFirst();
   }
 
   // Clear the list of shares.
-  while ( !sharesList.isEmpty() )
+  while (!sharesList.isEmpty())
   {
     delete sharesList.takeFirst();
   }
 }
 
 
-const QMap<QString,QString> &Smb4KGlobalPrivate::globalSambaOptions( bool read )
+const QMap<QString,QString> &Smb4KGlobalPrivate::globalSambaOptions(bool read)
 {
-  if (!m_samba_options_read || read)
+  if (read)
   {
-    // We are about to read the samba options. Set m_samba_options_read = true.
-    m_samba_options_read = true;
+    // Clear the options.
+    m_sambaOptions.clear();
     
-    // Clear the options list before reading.
-    m_samba_options.clear();
-
+    // Now search the smb.conf file and read the [global] section
+    // from it.
+    // With the introduction of Samba 4, the smb.conf file might also
+    // be named smb4.conf. Thus we need to search for two filenames.
+    // Please note that the file named smb.conf will always be picked
+    // if it exists.
     QStringList paths;
     paths << "/etc";
     paths << "/etc/samba";
     paths << "/usr/local/etc";
     paths << "/usr/local/etc/samba";
-
-    QFile file( "smb.conf" );
-    bool file_exists = false;
+    
+    QFile smbConf;
     QStringList contents;
 
-    // Locate the file and read its contents:
-    for ( int i = 0; i < paths.size(); ++i )
+    for (int i = 0; i < paths.size(); ++i)
     {
-      QDir::setCurrent( paths.at( i ) );
-
-      if ( (file_exists = file.exists()) )
+      QDir::setCurrent(paths.at(i));
+      QFile file1("smb.conf");
+      QFile file2("smb4.conf");
+      
+      if (file1.exists())
       {
-        if ( file.open( QIODevice::ReadOnly | QIODevice::Text ) )
-        {
-          QTextStream ts( &file );
-          // Note: With Qt 4.3 this seems to be obsolete, we'll keep
-          ts.setCodec( QTextCodec::codecForLocale() );
-
-          while ( !ts.atEnd() )
-          {
-            contents.append( ts.readLine( 0 ) );
-          }
-
-          file.close();
-        }
-        else
-        {
-          Smb4KNotification::openingFileFailed(file);
-          return m_samba_options;
-        }
-
+        smbConf.setFileName(QDir::currentPath()+QDir::separator()+file1.fileName());
+        break;
+      }
+      else if (file2.exists())
+      {
+        smbConf.setFileName(QDir::currentPath()+QDir::separator()+file2.fileName());
         break;
       }
       else
@@ -156,23 +145,48 @@ const QMap<QString,QString> &Smb4KGlobalPrivate::globalSambaOptions( bool read )
       }
     }
     
-    // Notify the user if the configuration file could not be found
-    // in the standard locations.
-    if (!file_exists)
+    if (smbConf.exists())
     {
-      Smb4KNotification::sambaConfigFileMissing();
+      if (smbConf.open(QIODevice::ReadOnly | QIODevice::Text))
+      {
+        QTextStream ts(&smbConf);
+        
+        while (!ts.atEnd())
+        {
+          contents.append(ts.readLine(0));
+        }
+        
+        smbConf.close();
+      }
+      else
+      {
+        Smb4KNotification::openingFileFailed(smbConf);
+        return m_sambaOptions;
+      }
+
+      m_sambaConfigMissing = false;
     }
     else
     {
-      // Do nothing
+      if (!m_sambaConfigMissing)
+      {
+        Smb4KNotification::sambaConfigFileMissing();
+        m_sambaConfigMissing = true;
+        return m_sambaOptions;
+      }
+      else
+      {
+        // Do nothing
+      }
     }
-
-    if ( !contents.isEmpty() )
+    
+    // Now process the contents of the smb.conf file.
+    if (!contents.isEmpty())
     {
       // Process the file contents.
-      for ( int i = contents.indexOf( "[global]", 0 ); i < contents.size(); ++i )
+      for (int i = contents.indexOf("[global]", 0); i < contents.size(); ++i)
       {
-        if ( i == -1 )
+        if (i == -1)
         {
           // The smb.conf file does not contain a global section.
           break;
@@ -182,65 +196,59 @@ const QMap<QString,QString> &Smb4KGlobalPrivate::globalSambaOptions( bool read )
           // Do nothing
         }
         
-        if ( contents.at( i ).trimmed().startsWith( '#' ) ||
-             contents.at( i ).trimmed().startsWith( ';' ) )
+        if (contents.at(i).trimmed().startsWith('#') || contents.at(i).trimmed().startsWith(';'))
         {
           // This is a comment. We do not need it.
           continue;
         }
-        else if ( contents.at( i ).trimmed().startsWith( QLatin1String( "include" ) ) )
+        else if (contents.at(i).trimmed().startsWith(QLatin1String("include")))
         {
           // Look for the include file and put its contents into the
-          // m_samba_options map.
-          file.setFileName( contents.at( i ).section( '=', 1, 1 ).trimmed() );
+          // m_sambaOptions map.
+          QFile includeFile(contents.at(i).section('=', 1, 1).trimmed());
 
-          if ( file.exists() )
+          if (includeFile.exists())
           {
-            if ( file.open( QIODevice::ReadOnly | QIODevice::Text ) )
+            if (includeFile.open(QIODevice::ReadOnly | QIODevice::Text))
             {
-              QTextStream ts( &file );
-              // Note: With Qt 4.3 this seems to be obsolete, we'll keep
-              // it for now.
-              ts.setCodec( QTextCodec::codecForLocale() );
+              QTextStream ts(&includeFile);
 
               QString buffer;
 
-              while( !ts.atEnd() )
+              while(!ts.atEnd())
               {
-                buffer = ts.readLine( 0 ).trimmed();
+                buffer = ts.readLine(0).trimmed();
 
-                if ( buffer.startsWith( '#' ) || buffer.startsWith( ';' ) )
+                if (buffer.startsWith('#') || buffer.startsWith(';'))
                 {
                   continue;
                 }
                 else
                 {
-                  QString key = buffer.section( '=', 0, 0 ).trimmed().toLower();
-                  m_samba_options[key] = buffer.section( '=', 1, 1 ).trimmed().toUpper();
-
+                  QString key = buffer.section('=', 0, 0).trimmed().toLower();
+                  m_sambaOptions[key] = buffer.section('=', 1, 1).trimmed().toUpper();
                   continue;
                 }
               }
             }
             else
             {
-              Smb4KNotification::openingFileFailed(file);
+              Smb4KNotification::openingFileFailed(includeFile);
               continue;
             }
           }
         }
-        else if ( contents.at( i ).startsWith( '[' ) &&
-                  !contents.at( i ).contains( "[global]", Qt::CaseSensitive ) )
+        else if (contents.at(i).startsWith('[') && !contents.at(i).contains("[global]", Qt::CaseSensitive))
         {
           // We reached the end of the [global] section. Stop here.
           break;
         }
         else
         {
-          // Put the entries of the [global] section into the m_samba_options
+          // Put the entries of the [global] section into the m_sambaOptions
           // map.
-          QString key = contents.at( i ).section( '=', 0, 0 ).trimmed().toLower();
-          m_samba_options[key] = contents.at( i ).section( '=', 1, 1 ).trimmed().toUpper();
+          QString key = contents.at(i).section('=', 0, 0).trimmed().toLower();
+          m_sambaOptions[key] = contents.at(i).section('=', 1, 1).trimmed().toUpper();
         }
       }
     }
@@ -251,9 +259,9 @@ const QMap<QString,QString> &Smb4KGlobalPrivate::globalSambaOptions( bool read )
 
     // Post-processing. Some values should be entered with their defaults, if they are
     // not already present.
-    if (!m_samba_options.contains("netbios name"))
+    if (!m_sambaOptions.contains("netbios name"))
     {
-      m_samba_options["netbios name"] = QHostInfo::localHostName().toUpper();
+      m_sambaOptions["netbios name"] = QHostInfo::localHostName().toUpper();
     }
     else
     {
@@ -265,72 +273,72 @@ const QMap<QString,QString> &Smb4KGlobalPrivate::globalSambaOptions( bool read )
     // Do nothing
   }
   
-  return m_samba_options;
+  return m_sambaOptions;
 }
 
 
 void Smb4KGlobalPrivate::setDefaultSettings()
 {
   // Samba options that have to be dynamically imported from smb.conf:
-  QMap<QString, QString> opts = globalSambaOptions(!m_samba_options_read);
+  QMap<QString, QString> opts = globalSambaOptions(true);
 
-  if ( !opts["netbios name"].isEmpty() )
+  if (!opts["netbios name"].isEmpty())
   {
-    Smb4KSettings::self()->netBIOSNameItem()->setDefaultValue( opts["netbios name"] );
+    Smb4KSettings::self()->netBIOSNameItem()->setDefaultValue(opts["netbios name"]);
 
-    if ( Smb4KSettings::netBIOSName().isEmpty() )
+    if (Smb4KSettings::netBIOSName().isEmpty())
     {
       Smb4KSettings::self()->netBIOSNameItem()->setDefault();
     }
   }
 
-  if ( !opts["workgroup"].isEmpty() )
+  if (!opts["workgroup"].isEmpty())
   {
-    Smb4KSettings::self()->domainNameItem()->setDefaultValue( opts["workgroup"] );
+    Smb4KSettings::self()->domainNameItem()->setDefaultValue(opts["workgroup"]);
 
-    if ( Smb4KSettings::domainName().isEmpty() )
+    if (Smb4KSettings::domainName().isEmpty())
     {
       Smb4KSettings::self()->domainNameItem()->setDefault();
     }
   }
 
-  if ( !opts["socket options"].isEmpty() )
+  if (!opts["socket options"].isEmpty())
   {
-    Smb4KSettings::self()->socketOptionsItem()->setDefaultValue( opts["socket options"] );
+    Smb4KSettings::self()->socketOptionsItem()->setDefaultValue(opts["socket options"]);
 
-    if ( Smb4KSettings::socketOptions().isEmpty() )
+    if (Smb4KSettings::socketOptions().isEmpty())
     {
       Smb4KSettings::self()->socketOptionsItem()->setDefault();
     }
   }
 
-  if ( !opts["netbios scope"].isEmpty() )
+  if (!opts["netbios scope"].isEmpty())
   {
-    Smb4KSettings::self()->netBIOSScopeItem()->setDefaultValue( opts["netbios scope"] );
+    Smb4KSettings::self()->netBIOSScopeItem()->setDefaultValue(opts["netbios scope"]);
 
-    if ( Smb4KSettings::netBIOSScope().isEmpty() )
+    if (Smb4KSettings::netBIOSScope().isEmpty())
     {
       Smb4KSettings::self()->netBIOSScopeItem()->setDefault();
     }
   }
 
-  if ( !opts["name resolve order"].isEmpty() )
+  if (!opts["name resolve order"].isEmpty())
   {
-    Smb4KSettings::self()->nameResolveOrderItem()->setDefaultValue( opts["name resolve order"] );
+    Smb4KSettings::self()->nameResolveOrderItem()->setDefaultValue(opts["name resolve order"]);
 
-    if ( Smb4KSettings::nameResolveOrder().isEmpty() )
+    if (Smb4KSettings::nameResolveOrder().isEmpty())
     {
       Smb4KSettings::self()->nameResolveOrderItem()->setDefault();
     }
   }
 
-  QHostAddress address( opts["interfaces"].section( ' ', 0, 0 ) );
+  QHostAddress address(opts["interfaces"].section(' ', 0, 0));
 
-  if ( address.protocol() != QAbstractSocket::UnknownNetworkLayerProtocol )
+  if (address.protocol() != QAbstractSocket::UnknownNetworkLayerProtocol)
   {
-    Smb4KSettings::self()->broadcastAddressItem()->setDefaultValue( address.toString() );
+    Smb4KSettings::self()->broadcastAddressItem()->setDefaultValue(address.toString());
 
-    if ( Smb4KSettings::broadcastAddress().isEmpty() )
+    if (Smb4KSettings::broadcastAddress().isEmpty())
     {
       Smb4KSettings::self()->broadcastAddressItem()->setDefault();
     }
@@ -346,10 +354,5 @@ void Smb4KGlobalPrivate::makeConnections()
 
 void Smb4KGlobalPrivate::slotAboutToQuit()
 {
-  Smb4KSettings::self()->writeConfig();
+  Smb4KSettings::self()->save();
 }
-
-
-#include "smb4kglobal_p.moc"
-
-
