@@ -1,9 +1,8 @@
 /***************************************************************************
-    smb4kglobal_p  -  These are the private helper classes of the 
-    Smb4KGlobal namespace.
+    These are the private helper classes of the Smb4KGlobal namespace.
                              -------------------
     begin                : Di Jul 24 2007
-    copyright            : (C) 2007-2015 by Alexander Reinholdt
+    copyright            : (C) 2007-2016 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -33,9 +32,9 @@
 #include "smb4kshare.h"
 
 // Qt includes
-#include <QtCore/QList>
-#include <QtCore/QMap>
-#include <QtCore/QObject>
+#include <QList>
+#include <QMap>
+#include <QObject>
 
 /**
  * This class is a private helper for the Smb4KGlobal namespace.
@@ -81,7 +80,7 @@ class Smb4KGlobalPrivate : public QObject
     /**
      * The global options defined in smb.conf
      */
-    const QMap<QString,QString> &globalSambaOptions( bool read );
+    const QMap<QString,QString> &globalSambaOptions(bool read);
 
     /**
      * Boolean that is TRUE when only foreign shares
@@ -126,8 +125,8 @@ class Smb4KGlobalPrivate : public QObject
     void slotAboutToQuit();
     
   private:
-    QMap<QString,QString> m_samba_options;
-    bool m_samba_options_read;
+    QMap<QString,QString> m_sambaOptions;
+    bool m_sambaConfigMissing;
 };
 
 #endif
