@@ -1,8 +1,8 @@
 /***************************************************************************
-    smb4khost  -  Smb4K's container class for information about a host.
+    Smb4K's container class for information about a host.
                              -------------------
     begin                : Sa Jan 26 2008
-    copyright            : (C) 2008-2012 by Alexander Reinholdt
+    copyright            : (C) 2008-2016 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -32,44 +32,42 @@
 #include "smb4kauthinfo.h"
 
 // Qt includes
-#include <QtCore/QStringList>
-#include <QtNetwork/QHostAddress>
+#include <QStringList>
+#include <QDebug>
+#include <QHostAddress>
 
 // KDE includes
-#include <kdebug.h>
-#include <kicon.h>
+#include <KIconThemes/KIconLoader>
 
 
 class Smb4KHostPrivate
 {
   public:
-    KUrl url;
+    QUrl url;
     QString workgroup;
     QHostAddress ip;
     QString comment;
-    QString serverString;
-    QString osString;
     bool isMaster;
 };
 
 
-Smb4KHost::Smb4KHost( const QString &name )
-: Smb4KBasicNetworkItem( Host ), d( new Smb4KHostPrivate )
+Smb4KHost::Smb4KHost(const QString &name)
+: Smb4KBasicNetworkItem(Host), d(new Smb4KHostPrivate)
 {
   d->isMaster     = false;
-  setHostName( name );
-  setIcon( KIcon( "network-server" ) );
+  setHostName(name);
+  setIcon(KDE::icon("network-server"));
 }
 
 
-Smb4KHost::Smb4KHost( const Smb4KHost &h )
-: Smb4KBasicNetworkItem( Host ), d( new Smb4KHostPrivate )
+Smb4KHost::Smb4KHost(const Smb4KHost &h)
+: Smb4KBasicNetworkItem(Host), d(new Smb4KHostPrivate)
 {
   *d = *h.d;
   
-  if ( icon().isNull() )
+  if (icon().isNull())
   {
-    setIcon( KIcon( "network-server" ) );
+    setIcon(KDE::icon("network-server"));
   }
   else
   {
@@ -79,10 +77,10 @@ Smb4KHost::Smb4KHost( const Smb4KHost &h )
 
 
 Smb4KHost::Smb4KHost()
-: Smb4KBasicNetworkItem( Host ), d( new Smb4KHostPrivate )
+: Smb4KBasicNetworkItem(Host), d(new Smb4KHostPrivate)
 {
   d->isMaster     = false;
-  setIcon( KIcon( "network-server" ) );
+  setIcon(KDE::icon("network-server"));
 }
 
 
@@ -91,10 +89,10 @@ Smb4KHost::~Smb4KHost()
 }
 
 
-void Smb4KHost::setHostName( const QString &name )
+void Smb4KHost::setHostName(const QString &name)
 {
-  d->url.setHost( name );
-  d->url.setProtocol( "smb" );
+  d->url.setHost(name);
+  d->url.setScheme("smb");
 }
 
 
@@ -108,9 +106,9 @@ QString Smb4KHost::unc() const
 {
   QString unc;
   
-  if ( !hostName().isEmpty() )
+  if (!hostName().isEmpty())
   {
-    unc = QString( "//%1" ).arg( hostName() );
+    unc = QString("//%1").arg(hostName());
   }
   else
   {
@@ -121,10 +119,10 @@ QString Smb4KHost::unc() const
 }
 
 
-void Smb4KHost::setURL( const KUrl &url )
+void Smb4KHost::setURL(const QUrl &url)
 {
   // Check validity.
-  if ( !url.isValid() )
+  if (!url.isValid())
   {
     return;
   }
@@ -134,7 +132,7 @@ void Smb4KHost::setURL( const KUrl &url )
   }
 
   // Check protocol
-  if ( url.protocol().isEmpty() || QString::compare( url.protocol(), "smb" ) == 0 )
+  if (url.scheme().isEmpty() || QString::compare(url.scheme(), "smb") == 0)
   {
     // Do nothing
   }
@@ -144,7 +142,7 @@ void Smb4KHost::setURL( const KUrl &url )
   }
 
   // Check that this is a host item
-  if ( url.hasPath() )
+  if (!url.path().isEmpty())
   {
     return;
   }
@@ -157,17 +155,17 @@ void Smb4KHost::setURL( const KUrl &url )
   d->url = url;
 
   // Force protocol
-  d->url.setProtocol( "smb" );
+  d->url.setScheme("smb");
 }
 
 
-KUrl Smb4KHost::url() const
+QUrl Smb4KHost::url() const
 {
   return d->url;
 }
 
 
-void Smb4KHost::setWorkgroupName( const QString &workgroup )
+void Smb4KHost::setWorkgroupName(const QString &workgroup)
 {
   d->workgroup = workgroup;
 }
@@ -179,9 +177,9 @@ QString Smb4KHost::workgroupName() const
 }
 
 
-void Smb4KHost::setIP( const QString &ip )
+void Smb4KHost::setIP(const QString &ip)
 {
-  d->ip.setAddress( ip );
+  d->ip.setAddress(ip);
 }
 
 
@@ -197,7 +195,7 @@ bool Smb4KHost::hasIP() const
 }
 
 
-void Smb4KHost::setComment( const QString &comment )
+void Smb4KHost::setComment(const QString &comment)
 {
   d->comment = comment;
 }
@@ -209,39 +207,7 @@ QString Smb4KHost::comment() const
 }
 
 
-void Smb4KHost::setInfo( const QString &serverString, const QString &osString )
-{
-  d->serverString = serverString;
-  d->osString     = osString;
-}
-
-
-void Smb4KHost::resetInfo()
-{
-  d->serverString.clear();
-  d->osString.clear();
-}
-
-
-bool Smb4KHost::hasInfo() const
-{
-  return (!d->osString.isEmpty() && !d->serverString.isEmpty());
-}
-
-
-QString Smb4KHost::serverString() const
-{
-  return d->serverString;
-}
-
-
-QString Smb4KHost::osString() const
-{
-  return d->osString;
-}
-
-
-void Smb4KHost::setIsMasterBrowser( bool master )
+void Smb4KHost::setIsMasterBrowser(bool master)
 {
   d->isMaster = master;
 }
@@ -255,7 +221,7 @@ bool Smb4KHost::isMasterBrowser() const
 
 bool Smb4KHost::isEmpty() const
 {
-  if ( !d->url.isEmpty() )
+  if (!d->url.isEmpty())
   {
     return false;
   }
@@ -264,7 +230,7 @@ bool Smb4KHost::isEmpty() const
     // Do nothing
   }
 
-  if ( !d->workgroup.isEmpty() )
+  if (!d->workgroup.isEmpty())
   {
     return false;
   }
@@ -273,7 +239,7 @@ bool Smb4KHost::isEmpty() const
     // Do nothing
   }
 
-  if ( !d->ip.isNull() )
+  if (!d->ip.isNull())
   {
     return false;
   }
@@ -282,7 +248,7 @@ bool Smb4KHost::isEmpty() const
     // Do nothing
   }
 
-  if ( !d->comment.isEmpty() )
+  if (!d->comment.isEmpty())
   {
     return false;
   }
@@ -291,33 +257,15 @@ bool Smb4KHost::isEmpty() const
     // Do nothing
   }
 
-  if ( !d->serverString.isEmpty() )
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-
-  if ( !d->osString.isEmpty() )
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-  
   // Do not include icon here.
 
   return true;
 }
 
 
-void Smb4KHost::setLogin( const QString &login )
+void Smb4KHost::setLogin(const QString &login)
 {
-  d->url.setUserName( login );
+  d->url.setUserName(login);
 }
 
 
@@ -327,9 +275,9 @@ QString Smb4KHost::login() const
 }
 
 
-void Smb4KHost::setPassword( const QString &passwd )
+void Smb4KHost::setPassword(const QString &passwd)
 {
-  d->url.setPassword( passwd );
+  d->url.setPassword(passwd);
 }
 
 
@@ -339,9 +287,9 @@ QString Smb4KHost::password() const
 }
 
 
-void Smb4KHost::setPort( int port )
+void Smb4KHost::setPort(int port)
 {
-  d->url.setPort( port );
+  d->url.setPort(port);
 }
 
 
@@ -351,11 +299,11 @@ int Smb4KHost::port() const
 }
 
 
-bool Smb4KHost::equals( Smb4KHost *host ) const
+bool Smb4KHost::equals(Smb4KHost *host) const
 {
-  Q_ASSERT( host );
+  Q_ASSERT(host);
 
-  if ( d->url != host->url() )
+  if (d->url != host->url())
   {
     return false;
   }
@@ -364,7 +312,7 @@ bool Smb4KHost::equals( Smb4KHost *host ) const
     // Do nothing
   }
 
-  if ( QString::compare( workgroupName(), host->workgroupName() ) != 0 )
+  if (QString::compare(workgroupName(), host->workgroupName()) != 0)
   {
     return false;
   }
@@ -373,7 +321,7 @@ bool Smb4KHost::equals( Smb4KHost *host ) const
     // Do nothing
   }
 
-  if ( QString::compare( ip(), host->ip() ) != 0 )
+  if (QString::compare(ip(), host->ip()) != 0)
   {
     return false;
   }
@@ -382,7 +330,7 @@ bool Smb4KHost::equals( Smb4KHost *host ) const
     // Do nothing
   }
 
-  if ( QString::compare( comment(), host->comment() ) != 0 )
+  if (QString::compare(comment(), host->comment()) != 0)
   {
     return false;
   }
@@ -391,33 +339,15 @@ bool Smb4KHost::equals( Smb4KHost *host ) const
     // Do nothing
   }
 
-  if ( QString::compare( serverString(), host->serverString() ) != 0 )
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-
-  if ( QString::compare( osString(), host->osString() ) != 0 )
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-  
   // Do not include icon here.
 
   return true;
 }
 
 
-void Smb4KHost::setAuthInfo( Smb4KAuthInfo *authInfo )
+void Smb4KHost::setAuthInfo(Smb4KAuthInfo *authInfo)
 {
-  d->url.setUserName( authInfo->userName() );
-  d->url.setPassword( authInfo->password() );
+  d->url.setUserName(authInfo->userName());
+  d->url.setPassword(authInfo->password());
 }
 
