@@ -1,8 +1,8 @@
 /***************************************************************************
-    smb4kmounter.h  -  The core class that mounts the shares.
+    The core class that mounts the shares.
                              -------------------
     begin                : Die Jun 10 2003
-    copyright            : (C) 2003-2014 by Alexander Reinholdt
+    copyright            : (C) 2003-2017 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -26,23 +26,17 @@
 #ifndef SMB4KMOUNTER_H
 #define SMB4KMOUNTER_H
 
-// application specific includes
-#include "smb4ksolidinterface.h"
-
 // Qt includes
-#include <QtCore/QObject>
-#include <QtCore/QFile>
-#include <QtCore/QString>
-#include <QtCore/QStringList>
-#include <QtCore/QScopedPointer>
+#include <QObject>
+#include <QFile>
+#include <QString>
+#include <QStringList>
+#include <QScopedPointer>
+#include <QMap>
+#include <QVariant>
 
 // KDE includes
-#include <kdemacros.h>
-#include <kauth.h>
-#include <kcompositejob.h>
-#include <kurl.h>
-
-using namespace KAuth;
+#include <KCoreAddons/KCompositeJob>
 
 // forward declarations
 class Smb4KShare;
@@ -50,7 +44,6 @@ class Smb4KAuthInfo;
 class Smb4KMountDialog;
 class Smb4KMountJob;
 class Smb4KUnmountJob;
-class Smb4KNetworkObject;
 class Smb4KMounterPrivate;
 
 /**
@@ -62,7 +55,7 @@ class Smb4KMounterPrivate;
  * @author Alexander Reinholdt <alexander.reinholdt@kdemail.net>
  */
 
-class KDE_EXPORT Smb4KMounter : public KCompositeJob
+class Q_DECL_EXPORT Smb4KMounter : public KCompositeJob
 {
   Q_OBJECT
 
@@ -72,7 +65,7 @@ class KDE_EXPORT Smb4KMounter : public KCompositeJob
     /**
      * The constructor.
      */
-    explicit Smb4KMounter( QObject *parent = 0 );
+    explicit Smb4KMounter(QObject *parent = 0);
     
     /**
      * The destructor.
@@ -84,13 +77,6 @@ class KDE_EXPORT Smb4KMounter : public KCompositeJob
      */
     static Smb4KMounter *self();
     
-    /**
-     * Aborts the mount/unmount process that is running for the share @p share.
-     *
-     * @param share           The Smb4KShare object
-     */
-    void abort( Smb4KShare *share );
-
     /**
      * Aborts all running processes at once.
      */
@@ -103,16 +89,7 @@ class KDE_EXPORT Smb4KMounter : public KCompositeJob
      * 
      * @param parent      The parent widget
      */
-    void mountShare( Smb4KShare *share,
-                     QWidget *parent = 0 );
-
-    /**
-     * Mount a share via a mount dialog. The mount dialog is opened and you have
-     * to enter the UNC and optionally the workgroup and IP address.
-     *
-     * @param parent      The parent widget of this dialog
-     */
-    void openMountDialog( QWidget *parent = 0 );
+    void mountShare(Smb4KShare *share, QWidget *parent = 0);
 
     /**
      * Mounts a list of shares at once.
@@ -121,8 +98,7 @@ class KDE_EXPORT Smb4KMounter : public KCompositeJob
      * 
      * @param parent      The parent widget
      */
-    void mountShares( const QList<Smb4KShare *> &shares,
-                      QWidget *parent = 0 );
+    void mountShares(const QList<Smb4KShare *> &shares, QWidget *parent = 0);
 
     /**
      * This function attempts to unmount a share. With the parameter @p silent you 
@@ -135,9 +111,7 @@ class KDE_EXPORT Smb4KMounter : public KCompositeJob
      * 
      * @param parent      The parent widget
      */
-    void unmountShare( Smb4KShare *share,
-                       bool silent = false,
-                       QWidget *parent = 0 );
+    void unmountShare(Smb4KShare *share, bool silent = false, QWidget *parent = 0);
     
     /**
      * This function attempts to unmount a list of shares. With the parameter @p silent 
@@ -150,9 +124,7 @@ class KDE_EXPORT Smb4KMounter : public KCompositeJob
      * 
      * @param parent      The parent widget
      */
-    void unmountShares( const QList<Smb4KShare *> &shares,
-                        bool silent = false,
-                        QWidget *parent = 0 );
+    void unmountShares(const QList<Smb4KShare *> &shares, bool silent = false, QWidget *parent = 0);
 
     /**
      * Unmounts all shares at once. This is a convenience function. It calls
@@ -160,16 +132,15 @@ class KDE_EXPORT Smb4KMounter : public KCompositeJob
      * 
      * @param parent      The parent widget
      */
-    void unmountAllShares( QWidget *parent = 0 );
+    void unmountAllShares(bool silent, QWidget *parent = 0);
 
     /**
-     * This function reports if the mount process for @p share is running.
+     * Mount a share via a mount dialog. The mount dialog is opened and you have
+     * to enter the UNC and optionally the workgroup and IP address.
      *
-     * @param share       The Smb4KShare object
-     *
-     * @returns TRUE if the process is running.
+     * @param parent      The parent widget of this dialog
      */
-    bool isRunning( Smb4KShare *share );
+    void openMountDialog(QWidget *parent = 0);
 
     /**
      * This function reports if the mounter is running or not.
@@ -185,19 +156,18 @@ class KDE_EXPORT Smb4KMounter : public KCompositeJob
     
   Q_SIGNALS:
     /**
-     * This signal is emitted whenever a share item was updated. This mainly happens
-     * from within the import process.
+     * This signal is emitted whenever a share item was updated.
      * 
      * @param share             The share item that was just updated.
      */ 
-    void updated( Smb4KShare *share );
+    void updated(Smb4KShare *share);
 
     /**
      * This signal is emitted when a share has successfully been mounted.
      *
      * @param share             The share that was just mounted.
      */
-    void mounted( Smb4KShare *share );
+    void mounted(Smb4KShare *share);
 
     /**
      * This signal is emitted after a share was unmounted and directly before
@@ -208,29 +178,19 @@ class KDE_EXPORT Smb4KMounter : public KCompositeJob
      *
      * @param share            The share that is going to be unmounted.
      */
-    void unmounted( Smb4KShare *share );
+    void unmounted(Smb4KShare *share);
     
     /**
-     * This signal is emitted when a mount/unmount process for the share 
-     * @p share is about to be started.
-     *
-     * @param share             The Smb4KShare object
-     *
+     * This signal is emitted when a process is about to start.
      * @param process           The kind of process
      */
-    void aboutToStart( Smb4KShare *share,
-                       int process );
+    void aboutToStart(int process);
 
     /**
-     * This signal is emitted when the mount/unmount process for the share 
-     * @p share finished.
-     *
-     * @param share             The Smb4KShare object
-     *
+     * This signal is emitted when a process finished.
      * @param process           The kind of process
      */
-    void finished( Smb4KShare *share,
-                   int process );
+    void finished(int process);
     
     /**
      * This signal is emitted every time a share was added to or removed
@@ -250,7 +210,7 @@ class KDE_EXPORT Smb4KMounter : public KCompositeJob
      *
      * @param event             The QTimerEvent event
      */
-    void timerEvent( QTimerEvent *event );
+    void timerEvent(QTimerEvent *event);
 
   protected Q_SLOTS:
     /**
@@ -264,91 +224,26 @@ class KDE_EXPORT Smb4KMounter : public KCompositeJob
      * really exits.
      */
     void slotAboutToQuit();
-    
+
     /**
-     * This slot is called when a job finished
-     * 
+     * This slot is called when a job finished.
      * @param job         The job that finished
      */
-    void slotJobFinished( KJob *job );
+    void slotJobFinished(KJob *job);
     
     /**
-     * Called when an authentication error occurred
+     * This slot is called when the online status changed. It is used 
+     * to initialize network actions when the network becomes available.
+     * @param online          TRUE if online otherwise FALSE
      */
-    void slotAuthError( Smb4KMountJob *job );
+    void slotOnlineStateChanged(bool online);
 
-    /**
-     * Called when mounting for one or more shares should be retried
-     */
-    void slotRetryMounting( Smb4KMountJob *job );
-
-    /**
-     * This slot is called whenever a share was successfully mounted by the 
-     * mount job.
-     *
-     * @param share       The share object
-     */
-    void slotShareMounted( Smb4KShare *share );
-    
-    /**
-     * This slot is called whenever a share was successfully unmounted by the
-     * unmount job.
-     * 
-     * @param reply       The share object
-     */
-    void slotShareUnmounted( Smb4KShare *share );
-    
-    /**
-     * This slot is called by the Solid interface when the network status
-     * changed. It is used to initialize network actions when the network
-     * became available.
-     *
-     * @param status          The new network status
-     */
-    void slotNetworkStatusChanged(Smb4KSolidInterface::ConnectionStatus status);
-
-    /**
-     * Called when a mount job started. It just emits the 
-     * aboutToStart( Smb4KShare *, MountShare ) signal for each share
-     * that is processed.
-     *
-     * @param shares          The list of shares that are going to be mounted
-     */
-    void slotAboutToStartMounting( const QList<Smb4KShare *> &shares );
-
-    /**
-     * Called when a mount job has finished. It just emits the
-     * finished( Smb4KShare *, MountShare ) signal for each share that 
-     * was processed.
-     *
-     * @param shares          The shares that were mounted
-     */
-    void slotFinishedMounting( const QList<Smb4KShare *> &shares );
-    
-    /**
-     * Called when an unmount job started. It just emits the 
-     * aboutToStart( Smb4KShare *, UnmountShare ) signal for each share
-     * that is processed.
-     *
-     * @param shares          The shares that are going to be unmounted
-     */
-    void slotAboutToStartUnmounting( const QList<Smb4KShare *> &shares );
-
-    /**
-     * Called when an unmount job has finished. It just emits the
-     * finished( Smb4KShare *, UnmountShare ) signal for each share that
-     * was processed.
-     *
-     * @param shares          The shares that were unmounted
-     */
-    void slotFinishedUnmounting( const QList<Smb4KShare *> &shares );
-    
     /**
      * Called when a mounted share has been stat'ed.
      * 
      * @param job             The KIO::StatJob
      */
-    void slotStatResult( KJob *job );
+    void slotStatResult(KJob *job);
     
     /**
      * This slot is called when the active profile changed.
@@ -363,6 +258,18 @@ class KDE_EXPORT Smb4KMounter : public KCompositeJob
      */
     void slotProfileMigrated(const QString &from, const QString &to);
     
+    /**
+     * This slot is called whenever a network share is mounted or 
+     * unmounted.
+     */
+    void slotTriggerImport();
+    
+    /**
+     * This slot is called whenever the configuration changed. It is used
+     * to trigger the importing of shares when certain settings changed.
+     */
+    void slotConfigChanged();
+    
   private:
     /**
      * Trigger the remounting of shares. If the parameter @p fill_list is
@@ -372,31 +279,33 @@ class KDE_EXPORT Smb4KMounter : public KCompositeJob
      * @param fill_list       Fill the internal list with shares that are 
      *                        to be remounted.
      */
-    void triggerRemounts( bool fill_list );
+    void triggerRemounts(bool fill_list);
 
     /**
      * Imports mounted shares.
      */
-    void import( bool check_inaccessible );
-
-    /**
-     * Checks the accessibility, the UID and GID and the usage of
-     * a share.
-     * 
-     * Only use this function when you are absolutely sure that a 
-     * share did not vanish, i.e. the server was not shut down. 
-     * Otherwise you will provoke lock-ups that render the 
-     * application at least temporarily useless.
-     * 
-     * @param share           The share that should be checked.
-     */
-    void check( Smb4KShare *share );
+    void import(bool checkInaccessible);
 
     /**
      * Save all shares that need to be remounted.
      */
     void saveSharesForRemount();
     
+    /**
+     * Fill the mount action arguments into a map.
+     */
+    bool fillMountActionArgs(Smb4KShare *share, QVariantMap &mountArgs);
+    
+    /**
+     * Fill the unmount action arguments into a map.
+     */
+    bool fillUnmountActionArgs(Smb4KShare *share, bool force, bool silent, QVariantMap &unmountArgs);
+    
+    /**
+     * Check the size, accessibility, ids, etc. of the share(s)
+     */
+    void check(Smb4KShare *share);
+    
     /**
      * Pointer to the Smb4KMounterPrivate class.
      */
