@@ -1,9 +1,8 @@
 /***************************************************************************
-    smb4kprofilemanager  -  This class manages the profiles that were
-    defined by the user.
+    This class manages the profiles that were defined by the user.
                              -------------------
     begin                : Mi Aug 06 2014
-    copyright            : (C) 2014 by Alexander Reinholdt
+    copyright            : (C) 2014-2016 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -28,15 +27,12 @@
 #define SMB4KPROFILEMANAGER_H
 
 // Qt includes
-#include <QtCore/QObject>
-#include <QtCore/QScopedPointer>
-#include <QtCore/QString>
-#include <QtCore/QStringList>
-#include <QtCore/QPair>
-#include <QtGui/QWidget>
-
-// KDE includes
-#include <kdemacros.h>
+#include <QObject>
+#include <QScopedPointer>
+#include <QString>
+#include <QStringList>
+#include <QPair>
+#include <QWidget>
 
 // forward declarations
 class Smb4KProfileManagerPrivate;
@@ -55,7 +51,7 @@ class Smb4KProfileManagerPrivate;
  */
 
 
-class KDE_EXPORT Smb4KProfileManager : public QObject
+class Q_DECL_EXPORT Smb4KProfileManager : public QObject
 {
   Q_OBJECT
   
@@ -97,7 +93,7 @@ class KDE_EXPORT Smb4KProfileManager : public QObject
     
     /**
      * Returns the list of profiles or an empty string list if the 
-     * the use of profiles is diabled.
+     * the use of profiles is disabled.
      * 
      * @returns the list of profiles.
      */
