@@ -1,8 +1,8 @@
 /***************************************************************************
-    smb4kshare  -  Smb4K's container class for information about a share.
+    Smb4K's container class for information about a share.
                              -------------------
     begin                : Mo Jan 28 2008
-    copyright            : (C) 2008-2015 by Alexander Reinholdt
+    copyright            : (C) 2008-2016 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -32,21 +32,22 @@
 #include "smb4kauthinfo.h"
 
 // Qt include
-#include <QtCore/QDir>
-#include <QtNetwork/QHostAddress>
+#include <QDir>
+#include <QHostAddress>
 
 // KDE includes
-#include <klocale.h>
-#include <kdebug.h>
-#include <kicon.h>
-#include <kiconloader.h>
-#include <kio/global.h>
+#define TRANSLATION_DOMAIN "smb4k-core"
+#include <KI18n/KLocalizedString>
+#include <KIOCore/KIO/Global>
+#include <KIconThemes/KIconLoader>
+#include <KIOCore/KMountPoint>
 
 
 class Smb4KSharePrivate
 {
   public:
-    KUrl url;
+    QUrl url;
+    QUrl homeUrl;
     QString workgroup;
     QString typeString;
     QString comment;
@@ -54,13 +55,13 @@ class Smb4KSharePrivate
     QString path;
     bool inaccessible;
     bool foreign;
-    int filesystem;
     KUser user;
     KUserGroup group;
     qulonglong totalSpace;
     qulonglong freeSpace;
     qulonglong usedSpace;
     bool mounted;
+    QString filesystem;
 };
 
 
@@ -70,7 +71,7 @@ Smb4KShare::Smb4KShare(const QString &host, const QString &name)
   d->typeString   = "Disk";
   d->inaccessible = false;
   d->foreign      = false;
-  d->filesystem   = Unknown;
+  d->filesystem   = QString();
   d->user         = KUser(KUser::UseRealUserID);
   d->group        = KUserGroup(KUser::UseRealUserID);
   d->totalSpace   = -1;
@@ -89,15 +90,15 @@ Smb4KShare::Smb4KShare(const QString &unc)
   d->typeString   = "Disk";
   d->inaccessible = false;
   d->foreign      = false;
-  d->filesystem   = Unknown;
+  d->filesystem   = QString();
   d->user         = KUser(KUser::UseRealUserID);
   d->group        = KUserGroup(KUser::UseRealUserID);
   d->totalSpace   = -1;
   d->freeSpace    = -1;
   d->usedSpace    = -1;
   d->mounted      = false;
-  d->url.setUrl(unc, KUrl::TolerantMode);
-  d->url.setProtocol("smb");
+  d->url.setUrl(unc, QUrl::TolerantMode);
+  d->url.setScheme("smb");
   setShareIcon();
 }
 
@@ -125,14 +126,14 @@ Smb4KShare::Smb4KShare()
   d->typeString   = "Disk";
   d->inaccessible = false;
   d->foreign      = false;
-  d->filesystem   = Unknown;
+  d->filesystem   = QString();
   d->user         = KUser(KUser::UseRealUserID);
   d->group        = KUserGroup(KUser::UseRealUserID);
   d->totalSpace   = -1;
   d->freeSpace    = -1;
   d->usedSpace    = -1;
   d->mounted      = false;
-  d->url.setProtocol("smb");
+  d->url.setScheme("smb");
 }
 
 
@@ -152,34 +153,21 @@ void Smb4KShare::setShareName(const QString &name)
     d->url.setPath('/'+name.trimmed());
   }
   
-  d->url.setProtocol("smb");
+  d->url.setScheme("smb");
 }
 
 
 QString Smb4KShare::shareName() const
 {
-  // Since users might come up with very weird share names,
-  // we are careful and do not use QString::remove("/"), but
-  // only remove preceding and trailing slashes.
-  QString share_name = d->url.path(KUrl::RemoveTrailingSlash);
-  
-  if (share_name.startsWith('/'))
-  {
-    share_name = share_name.remove(0, 1);
-  }
-  else
-  {
-    // Do nothing
-  }
-  
-  return share_name;
+  QString share_name = d->url.path();
+  return share_name.remove('/');
 }
 
 
 void Smb4KShare::setHostName(const QString &hostName)
 {
   d->url.setHost(hostName.trimmed());
-  d->url.setProtocol("smb");
+  d->url.setScheme("smb");
 }
 
 
@@ -223,7 +211,7 @@ QString Smb4KShare::homeUNC() const
 }
 
 
-void Smb4KShare::setURL(const KUrl &url)
+void Smb4KShare::setURL(const QUrl &url)
 {
   // Check validity.
   if (!url.isValid())
@@ -236,7 +224,7 @@ void Smb4KShare::setURL(const KUrl &url)
   }
 
   // Check protocol
-  if (url.protocol().isEmpty() || QString::compare(url.protocol(), "smb") == 0)
+  if (url.scheme().isEmpty() || QString::compare(url.scheme(), "smb") == 0)
   {
     // Do nothing
   }
@@ -246,7 +234,7 @@ void Smb4KShare::setURL(const KUrl &url)
   }
   
   // Check that the share name is present
-  if (!url.hasPath() || url.path(KUrl::RemoveTrailingSlash).endsWith('/'))
+  if (url.path().isEmpty() || (url.path().size() == 1 && url.path().endsWith('/')))
   {
     return;
   }
@@ -259,33 +247,24 @@ void Smb4KShare::setURL(const KUrl &url)
   d->url = url;
   
   // Force the protocol
-  d->url.setProtocol("smb");
+  d->url.setScheme("smb");
 }
 
 
-void Smb4KShare::setURL(const QString &url)
-{
-  KUrl u;
-  u.setUrl(url, KUrl::TolerantMode);
-
-  setURL(u);
-}
-
-
-KUrl Smb4KShare::url() const
+QUrl Smb4KShare::url() const
 {
   return d->url;
 }
 
 
-KUrl Smb4KShare::homeURL() const
+QUrl Smb4KShare::homeURL() const
 {
-  KUrl url;
+  QUrl url;
   
   if (isHomesShare() && !d->url.userName().isEmpty())
   {
     url = d->url;
-    url.setPath(d->url.userName());
+    url.setPath('/'+d->url.userName(), QUrl::TolerantMode);
   }
   else
   {
@@ -313,6 +292,12 @@ QString Smb4KShare::hostUNC() const
 }
 
 
+QString Smb4KShare::displayString() const
+{
+  return i18n("%1 on %2", shareName(), hostName());
+}
+
+
 void Smb4KShare::setWorkgroupName(const QString &workgroup)
 {
   d->workgroup = workgroup;
@@ -345,7 +330,7 @@ QString Smb4KShare::translatedTypeString() const
     return i18n("Disk");
   }
   else if (QString::compare(d->typeString, "Print") == 0 ||
-            QString::compare(d->typeString, "Printer") == 0)
+           QString::compare(d->typeString, "Printer") == 0)
   {
     return i18n("Printer");
   }
@@ -382,6 +367,12 @@ QString Smb4KShare::hostIP() const
 }
 
 
+bool Smb4KShare::hasHostIP() const
+{
+  return !d->ip.isNull();
+}
+
+
 bool Smb4KShare::isHidden() const
 {
   return d->url.path().endsWith('$');
@@ -448,77 +439,47 @@ bool Smb4KShare::isForeign() const
 }
 
 
-void Smb4KShare::setFileSystem(FileSystem filesystem)
-{
-  d->filesystem = filesystem;
-}
-
-
-Smb4KShare::FileSystem Smb4KShare::fileSystem() const
-{
-  return static_cast<FileSystem>(d->filesystem);
-}
-
-
 QString Smb4KShare::fileSystemString() const
 {
-  switch (d->filesystem)
+  if (!path().isEmpty() && d->filesystem.isEmpty())
   {
-    case CIFS:
-    {
-      return "cifs";
-    }
-    case SMBFS:
-    {
-      return "smbfs";
-    }
-    default:
-    {
-      break;
-    }
+    KMountPoint::Ptr mp = KMountPoint::currentMountPoints().findByPath(path());
+    d->filesystem = mp->mountType().toUpper();
   }
-
-  return QString();
+  else
+  {
+    // Do nothing
+  }
+  
+  return d->filesystem;
 }
 
 
-void Smb4KShare::setUID(K_UID uid)
+void Smb4KShare::setUser(const KUser &user)
 {
-  d->user = KUser(uid);
+  d->user = user;
 }
 
 
-uid_t Smb4KShare::uid() const
+KUser Smb4KShare::user() const
 {
-  return d->user.uid();
+  return d->user;
 }
 
 
-QString Smb4KShare::owner() const
+void Smb4KShare::setGroup(const KUserGroup &group)
 {
-  return d->user.loginName();
+  d->group = group;
 }
 
 
-void Smb4KShare::setGID(K_GID gid)
+KUserGroup Smb4KShare::group() const
 {
-  d->group = KUserGroup(gid);
+  return d->group;
 }
 
 
-K_GID Smb4KShare::gid() const
-{
-  return d->group.gid();
-}
-
-
-QString Smb4KShare::group() const
-{
-  return d->group.name();
-}
-
-
-void Smb4KShare::setIsMounted(bool mounted)
+void Smb4KShare::setMounted(bool mounted)
 {
   if (!isPrinter())
   {
@@ -710,18 +671,8 @@ bool Smb4KShare::equals(Smb4KShare *share, CheckFlags flag) const
         // Do nothing
       }
 
-      // File system
-      if (fileSystem() != share->fileSystem())
-      {
-        return false;
-      }
-      else
-      {
-        // do nothing
-      }
-
       // UID
-      if (uid() != share->uid())
+      if (user().userId().nativeId() != share->user().userId().nativeId())
       {
         return false;
       }
@@ -731,7 +682,7 @@ bool Smb4KShare::equals(Smb4KShare *share, CheckFlags flag) const
       }
 
       // GID
-      if (gid() != share->gid())
+      if (group().groupId().nativeId() != share->group().groupId().nativeId())
       {
         return false;
       }
@@ -922,18 +873,8 @@ bool Smb4KShare::equals(Smb4KShare *share, CheckFlags flag) const
         // Do nothing
       }
 
-      // File system
-      if (fileSystem() != share->fileSystem())
-      {
-        return false;
-      }
-      else
-      {
-        // do nothing
-      }
-
       // UID
-      if (uid() != share->uid())
+      if (user().userId().nativeId() != share->user().userId().nativeId())
       {
         return false;
       }
@@ -943,7 +884,7 @@ bool Smb4KShare::equals(Smb4KShare *share, CheckFlags flag) const
       }
 
       // GID
-      if (gid() != share->gid())
+      if (group().groupId().nativeId() != share->group().groupId().nativeId())
       {
         return false;
       }
@@ -1006,26 +947,6 @@ bool Smb4KShare::equals(Smb4KShare *share, CheckFlags flag) const
         // Do nothing
       }
 
-      // File system
-      if (fileSystem() != share->fileSystem())
-      {
-        return false;
-      }
-      else
-      {
-        // do nothing
-      }
-
-      // Mounted
-      if (isMounted() != share->isMounted())
-      {
-        return false;
-      }
-      else
-      {
-        // Do nothing
-      }
-
       break;
     }    
     default:
@@ -1074,7 +995,7 @@ bool Smb4KShare::isEmpty(CheckFlags flag) const
         return false;
       }
 
-      if (d->filesystem != Unknown)
+      if (!d->filesystem.isEmpty())
       {
         return false;
       }
@@ -1132,7 +1053,7 @@ bool Smb4KShare::isEmpty(CheckFlags flag) const
         return false;
       }
 
-      if (d->filesystem != Unknown)
+      if (!d->filesystem.isEmpty())
       {
         return false;
       }
@@ -1173,9 +1094,8 @@ void Smb4KShare::setMountData(Smb4KShare *share)
     d->path         = share->path();
     d->inaccessible = share->isInaccessible();
     d->foreign      = share->isForeign();
-    d->filesystem   = share->fileSystem();
-    d->user         = KUser(share->uid());
-    d->group        = KUserGroup(share->gid());
+    d->user         = share->user();
+    d->group        = share->group();
     d->totalSpace   = share->totalDiskSpace();
     d->freeSpace    = share->freeDiskSpace();
     d->usedSpace    = share->usedDiskSpace();
@@ -1192,12 +1112,9 @@ void Smb4KShare::setMountData(Smb4KShare *share)
 
 void Smb4KShare::resetMountData()
 {
-  // The login name is not reset here, because it is also
-  // needed for things that are not mount-related.
   d->path.clear();
   d->inaccessible = false;
   d->foreign      = false;
-  d->filesystem   = Unknown;
   d->user         = KUser(KUser::UseRealUserID);
   d->group        = KUserGroup(KUser::UseRealUserID);
   d->totalSpace   = -1;
@@ -1285,12 +1202,6 @@ QString Smb4KShare::password() const
 }
 
 
-bool Smb4KShare::hasHostIP() const
-{
-  return !d->ip.isNull();
-}
-
-
 void Smb4KShare::setShareIcon()
 {
   // We have three base icons: The remote folder, the locked folder
@@ -1311,10 +1222,7 @@ void Smb4KShare::setShareIcon()
 
     if (isForeign())
     {
-      overlays << "";
-      overlays << "flag-red";
-      // FIXME (Smb4K 2.0): Use 'view-media-artist' instead of 'flag-red'.
-//       overlays << "view-media-artist";
+      overlays << "task-attention";
     }
     else
     {
@@ -1322,34 +1230,22 @@ void Smb4KShare::setShareIcon()
     }
 
     // The icon
-    KIcon icon;
+    QIcon icon;
     
     if (!isInaccessible())
     {
-      icon = KIcon("folder-remote", KIconLoader::global(), overlays);
-      
-      // FIXME (Smb4K 2.0): Use 'folder-network' instead of 'folder-remote'.
-//       icon = KIcon("folder-network", KIconLoader::global(), overlays);
-//       
-//       if (icon.isNull())
-//       {
-//         icon = KIcon("folder-remote", KIconLoader::global(), overlays);
-//       }
-//       else
-//       {
-//         // Nichts tun
-//       }
+      icon = KDE::icon("folder-network", overlays);
     }
     else
     {
-      icon = KIcon("folder-locked", KIconLoader::global(), overlays);
+      icon = KDE::icon("folder-locked", overlays);
     }
     
     setIcon(icon);
   }
   else
   {
-    setIcon(KIcon("printer"));
+    setIcon(KDE::icon("printer"));
   }
 }
 
