@@ -1,8 +1,8 @@
 /***************************************************************************
-    smb4kshare  -  Smb4K's container class for information about a share.
+    Smb4K's container class for information about a share.
                              -------------------
     begin                : Mo Jan 28 2008
-    copyright            : (C) 2008-2015 by Alexander Reinholdt
+    copyright            : (C) 2008-2016 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -30,21 +30,20 @@
 #include "smb4kbasicnetworkitem.h"
 
 // Qt includes
-#include <QtCore/QString>
-#include <QtCore/QStringList>
-#include <QtCore/QtGlobal>
-#include <QtCore/QScopedPointer>
+#include <QString>
+#include <QStringList>
+#include <QtGlobal>
+#include <QScopedPointer>
+#include <QUrl>
 
 // KDE includes
-#include <kurl.h>
-#include <kuser.h>
-#include <kdemacros.h>
+#include <KCoreAddons/KUser>
 
 // forward declarations
 class Smb4KAuthInfo;
 class Smb4KSharePrivate;
 
-class KDE_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
+class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
 {
   friend class Smb4KSharePrivate;
   
@@ -61,8 +60,7 @@ class KDE_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      *
      * @param shareName     The name of the share.
      */
-    Smb4KShare(const QString &hostName,
-                const QString &shareName);
+    Smb4KShare(const QString &hostName, const QString &shareName);
 
     /**
      * This constructor takes the UNC @p unc (in the form [smb:]//[USER@]HOST/SHARE) as
@@ -159,21 +157,14 @@ class KDE_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      * 
      * @param url             The URL of the network item
      */
-    void setURL(const KUrl &url);
-    
-    /**
-     * Sets the URL of the share.
-     *
-     * @param url             The URL of the network item
-     */
-    void setURL(const QString &url);
+    void setURL(const QUrl &url);
     
     /**
      * Returns the URL of the share.
      * 
      * @returns the URL of the share.
      */
-    KUrl url() const;
+    QUrl url() const;
                                                        
     /**
      * In case of a 'homes' share, this function returns the URL of the user's 
@@ -184,7 +175,7 @@ class KDE_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      * 
      * @returns the user's home repository's URL.
      */
-    KUrl homeURL() const;
+    QUrl homeURL() const;
 
     /**
      * Returns the host's UNC (Uniform Naming Convention string) in the form //HOST.
@@ -199,6 +190,13 @@ class KDE_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      * @returns the UNC of the host.
      */
     QString hostUNC() const;
+    
+    /**
+     * Returns the display string. Prefer this over all other alternatives in your
+     * GUI.
+     * @returns the display string.
+     */
+    QString displayString() const;
 
     /**
      * Set the workgroup where the host is located that offers this share.
@@ -269,6 +267,13 @@ class KDE_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      * @returns the IP address of the host or an empty string.
      */
     QString hostIP() const;
+    
+    /**
+     * Returns TRUE if the host's IP address is set and FALSE otherwise.
+     * 
+     * @returns TRUE if the host's IP address is set and FALSE otherwise.
+     */
+    bool hasHostIP() const;
 
     /**
      * If the share is a hidden one, i.e. it ends with a '$', this function returns
@@ -342,28 +347,6 @@ class KDE_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      */
     bool isForeign() const;
 
-    /**
-     * Enumeration for the file system
-     */
-    enum FileSystem{ CIFS,
-                     SMBFS,
-                     Unknown };
-
-    /**
-     * Set the file system with which the share is mounted.
-     *
-     * @param filesystem      The file system of the mounted share.
-     */
-    void setFileSystem(FileSystem filesystem);
-
-    /**
-     * Returns the file system of the share. If it wasn't set, FileSystem::Unknown
-     * is returned.
-     *
-     * @returns the file system of the share.
-     */
-    FileSystem fileSystem() const;
-
     /**
      * Returns the file system as string in capital letters. If no file system
      * was specified, an empty string is returned.
@@ -373,50 +356,30 @@ class KDE_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
     QString fileSystemString() const;
 
     /**
-     * Sets the UID of the owner of this share.
-     *
-     * @param uid             The UID of the owner
+     * Sets the owner of this share.
+     * @param user             The UID of the owner
      */
-    void setUID(K_UID uid);
+    void setUser(const KUser &user);
 
     /**
-     * Returns the UID of the owner of this share or the UID of the user, if
-     * the UID was not set.
-     *
-     * @returns the UID of the owner.
+     * Returns the owner of this share or the current user, if
+     * the owner was not set using @see setUser().
+     * @returns the owner.
      */
-    K_UID uid() const;
+    KUser user() const;
     
     /**
-     * Returns the owner's login name. If the owner's UID was not set, the login
-     * name of the user is returned.
-     *
-     * @returns the owner's login name.
+     * Set the group that owns this share.
+     * @param group            The owning GID
      */
-    QString owner() const;
+    void setGroup(const KUserGroup &group);
 
     /**
-     * Set the owning GID of this share.
-     *
-     * @param gid             The owning GID
+     * Returns the group that owns this share or the current group, if
+     * the group was not set using @see setGroup().
+     * @returns the group.
      */
-    void setGID(K_GID gid);
-
-    /**
-     * Returns the GID of the owner of this share or the GID of the user, if
-     * the GID was not set.
-     *
-     * @returns the GID of the owner.
-     */
-    K_GID gid() const;
-
-    /**
-     * Returns the owning group name. If the owning GID was not set, the group
-     * name of the user is returned.
-     *
-     * @returns the owning group name.
-     */
-    QString group() const;
+    KUserGroup group() const;
 
     /**
      * Sets the value of the total disk space that is available on the share. If 
@@ -522,7 +485,7 @@ class KDE_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      * @enum LocalOnly          Only those values are compared that are of local 
      *                          importance
      * @enum MinimalLocalOnly   Only those values are compared that have local importance
-     *                          and are absolutely for a comparison
+     *                          and are absolutely necessary for a comparison
      */
     enum CheckFlags{ Full,
                      NetworkOnly,
@@ -545,8 +508,7 @@ class KDE_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      *
      * @returns TRUE if the data that was compared is the same.
      */
-    bool equals(Smb4KShare *share,
-                 CheckFlags flag) const;
+    bool equals(Smb4KShare *share, CheckFlags flag) const;
                  
     /**
      * Operator to check if two shares are equal. This operator performs a full check.
@@ -572,7 +534,7 @@ class KDE_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      *
      * @param mounted         Should be set to TRUE if the share was mounted.
      */
-    void setIsMounted(bool mounted);
+    void setMounted(bool mounted);
 
     /**
      * This function returns TRUE if the share has been mounted and FALSE
@@ -583,17 +545,16 @@ class KDE_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
     bool isMounted() const;
 
     /**
-     * This convenience function sets the mount related data. It is copied
+     * This convenience function sets the mount related data that is copied
      * from @p share.
      *
      * @param share           The share object from where the mount related
      *                        data should be copied.
      */
     void setMountData(Smb4KShare *share);
-
+    
     /**
-     * This convenience function resets the mount related data (mount point,
-     * file system, etc.).
+     * This convenience function resets the mount related data.
      */
     void resetMountData();
 
@@ -657,13 +618,6 @@ class KDE_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      */
     QString password() const;
     
-    /**
-     * Returns TRUE if the host's IP address is set and FALSE otherwise.
-     * 
-     * @returns TRUE if the host's IP address is set and FALSE otherwise.
-     */
-    bool hasHostIP() const;
-
   private:
     /**
      * Set up the shares icon.
