@@ -1,9 +1,8 @@
 /***************************************************************************
-    smb4kwalletmanager_p  -  Private helper classes for the wallet manager
-                             of Smb4K.
+    Private helper classes for the wallet manager of Smb4K.
                              -------------------
     begin                : Mo Dez 31 2012
-    copyright            : (C) 2012-2014 by Alexander Reinholdt
+    copyright            : (C) 2012-2016 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -32,8 +31,8 @@
 #include "smb4kbasicnetworkitem.h"
 
 // KDE includes
-#include <kwallet.h>
-#include <kpassworddialog.h>
+#include <KWallet/KWallet>
+#include <KWidgetsAddons/KPasswordDialog>
 
 
 class Smb4KPasswordDialog : public KPasswordDialog
@@ -41,15 +40,15 @@ class Smb4KPasswordDialog : public KPasswordDialog
   Q_OBJECT
   
   public:
-    Smb4KPasswordDialog( Smb4KBasicNetworkItem *networkItem,
+    Smb4KPasswordDialog(Smb4KBasicNetworkItem *networkItem,
                          const QMap<QString,QString> &knownLogins,
-                         QWidget *parent = 0 );
+                         QWidget *parent = 0);
     virtual ~Smb4KPasswordDialog();
 
   protected Q_SLOTS:
-    void slotGotUsernameAndPassword( const QString &user,
-                                     const QString &pass,
-                                     bool keep );
+    void slotGotUsernameAndPassword(const QString &user,
+                                    const QString &pass,
+                                    bool keep);
 
   private:
     Smb4KBasicNetworkItem *m_item;
