@@ -1,8 +1,8 @@
 /***************************************************************************
-    smb4kmounthelper  -  The helper that mounts and unmounts shares.
+    The helper that mounts and unmounts shares.
                              -------------------
     begin                : Sa Okt 16 2010
-    copyright            : (C) 2010-2015 by Alexander Reinholdt
+    copyright            : (C) 2010-2017 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -30,7 +30,7 @@
 #include <QObject>
 
 // KDE includes
-#include <kauth.h>
+#include <KAuth/KAuthActionReply>
 
 using namespace KAuth;
 
@@ -41,29 +41,24 @@ class Smb4KMountHelper : public QObject
   public slots:
     /**
      * Mounts a CIFS/SMBFS share.
-     *
-     * The following arguments are recognized:
-     * @arg command     The full mount command (mandatory)
-     * @arg url         The URL of the share (mandatory)
-     * @arg mountpoint  The mountpoint of the share (mandatory)
-     * @arg workgroup   The workgroup of the share (optional)
-     * @arg comments    The comment of the share (optional)
-     * @arg ip          The IP address of the host that offers the share (optional)
-     * @arg key         The key of this action (optional, mandatory for Smb4K)
-     * @arg home_dir    The home directory of the user (mandatory under FreeBSD)
      */
-    ActionReply mount( const QVariantMap &args );
+    ActionReply mount(const QVariantMap &args);
 
     /**
      * Unmounts a CIFS/SMBFS share.
-     *
-     * The following arguments are recognized:
-     * @arg command     The full unmount command (mandatory)
-     * @arg url         The URL of the share (optional, mandatory for Smb4K)
-     * @arg mountpoint  The mountpoint of the share (mandatory)
-     * @arg key         The key of this action (optional, mandatory for Smb4K)
      */
-    ActionReply unmount( const QVariantMap &args );
+    ActionReply unmount(const QVariantMap &args);
+    
+  private:
+    /**
+     * Unmount the shares one by one.
+     */
+    ActionReply unmountOneByOne(const QVariantMap &args);
+    
+    /**
+     * Unmount all shares at once.
+     */
+    ActionReply unmountAtOnce(const QVariantMap &args);
 };
 
 #endif
