@@ -2,7 +2,7 @@
     smb4ksystemtray  -  This is the system tray window class of Smb4K.
                              -------------------
     begin                : Mi Jun 13 2007
-    copyright            : (C) 2007-2014 by Alexander Reinholdt
+    copyright            : (C) 2007-2016 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -38,62 +38,67 @@
 #include "core/smb4kmounter.h"
 #include "core/smb4kscanner.h"
 
+// Qt includes
+#include <QMenu>
+
 // KDE specific includes
-#include <kiconloader.h>
-#include <klocale.h>
-#include <kdebug.h>
-#include <kaction.h>
-#include <kmessagebox.h>
-#include <kconfigdialog.h>
-#include <kicon.h>
-#include <kstandardaction.h>
-#include <kpluginloader.h>
-#include <kpluginfactory.h>
-#include <kactioncollection.h>
-#include <kmenu.h>
+#include <KIconThemes/KIconLoader>
+#include <KI18n/KLocalizedString>
+#include <KConfigWidgets/KStandardAction>
+#include <KConfigWidgets/KConfigDialog>
+#include <KXmlGui/KActionCollection>
+#include <KCoreAddons/KPluginLoader>
+#include <KCoreAddons/KPluginFactory>
+#include <KWidgetsAddons/KMessageBox>
 
 using namespace Smb4KGlobal;
 
 
-Smb4KSystemTray::Smb4KSystemTray( QWidget *parent )
-: KStatusNotifierItem( "smb4k_systemtray", parent )
+Smb4KSystemTray::Smb4KSystemTray(QWidget *parent)
+: KStatusNotifierItem("smb4k_systemtray", parent)
 {
-  setIconByName( "smb4k" );
-  setToolTip( KIconLoader::global()->loadIcon( "smb4k", KIconLoader::NoGroup ), i18n( "Smb4K" ), i18n( "Advanced Network Neighborhood Browser" ) );
+  setIconByName("smb4k");
+  setToolTip(KDE::icon("smb4k"), i18n("Smb4K"), i18n("Advanced Network Neighborhood Browser"));
   
   // Show the icon to the user. It will become passive, if the scanner
   // could not find something and no shares were mounted.
-  setStatus( KStatusNotifierItem::Active );
+  setStatus(KStatusNotifierItem::Active);
 
   // Set up the context menu (skeleton):
-  KAction *manual_mount = new KAction( KIcon( "view-form", KIconLoader::global(), QStringList( "emblem-mounted" ) ),
-                          i18n( "&Open Mount Dialog" ), actionCollection() );
-  KAction *configure    = KStandardAction::preferences( this, SLOT(slotConfigDialog()),
-                          actionCollection() );
+  QAction *manual_mount = new QAction(KDE::icon("view-form", QStringList("emblem-mounted")),
+                          i18n("&Open Mount Dialog"), this);
+  QAction *configure = KStandardAction::preferences(this, SLOT(slotConfigDialog()),
+                       this);
   
-  Smb4KSharesMenu *shares_menu = new Smb4KSharesMenu( associatedWidget(), this );
-  Smb4KBookmarkMenu *bookmark_menu = new Smb4KBookmarkMenu( Smb4KBookmarkMenu::SystemTray, associatedWidget(), this );
+  Smb4KSharesMenu *shares_menu = new Smb4KSharesMenu(associatedWidget(), this);
+  Smb4KBookmarkMenu *bookmark_menu = new Smb4KBookmarkMenu(Smb4KBookmarkMenu::SystemTray, associatedWidget(), this);
   Smb4KProfilesMenu *profiles_menu = new Smb4KProfilesMenu(this);
+  
+  addAction("manual_mount", manual_mount);
+  addAction("configure", configure);
+  addAction("shares_menu", shares_menu);
+  addAction("bookmark_menu", bookmark_menu);
+  addAction("profiles_menu", profiles_menu);
 
-  contextMenu()->addAction( shares_menu );
-  contextMenu()->addAction( bookmark_menu );
+  contextMenu()->addAction(shares_menu);
+  contextMenu()->addAction(bookmark_menu);
   contextMenu()->addAction(profiles_menu);
   contextMenu()->addSeparator();
-  contextMenu()->addAction( manual_mount );
-  contextMenu()->addAction( configure );
+  contextMenu()->addAction(manual_mount);
+  contextMenu()->addAction(configure);
 
   // Connections:
-  connect( manual_mount,                 SIGNAL(triggered(bool)),
-           this,                         SLOT(slotMountDialog(bool)) );
+  connect(manual_mount,                 SIGNAL(triggered(bool)),
+           this,                         SLOT(slotMountDialog(bool)));
 
-  connect( Smb4KMounter::self(),         SIGNAL(mounted(Smb4KShare*)),
-           this,                         SLOT(slotSetStatus()) );
+  connect(Smb4KMounter::self(),         SIGNAL(mounted(Smb4KShare*)),
+           this,                         SLOT(slotSetStatus()));
 
-  connect( Smb4KMounter::self(),         SIGNAL(unmounted(Smb4KShare*)),
-           this,                         SLOT(slotSetStatus()) );
+  connect(Smb4KMounter::self(),         SIGNAL(unmounted(Smb4KShare*)),
+           this,                         SLOT(slotSetStatus()));
 
-  connect( Smb4KScanner::self(),         SIGNAL(workgroups(QList<Smb4KWorkgroup*>)),
-           this,                         SLOT(slotSetStatus()) );
+  connect(Smb4KScanner::self(),         SIGNAL(workgroups(QList<Smb4KWorkgroup*>)),
+           this,                         SLOT(slotSetStatus()));
 }
 
 
@@ -107,7 +112,7 @@ void Smb4KSystemTray::loadSettings()
   // Adjust the bookmarks menu.
   Smb4KBookmarkMenu *bookmark_menu = findChild<Smb4KBookmarkMenu *>();
 
-  if ( bookmark_menu )
+  if (bookmark_menu)
   {
     bookmark_menu->refreshMenu();
   }
@@ -119,7 +124,7 @@ void Smb4KSystemTray::loadSettings()
   // Adjust the shares menu.
   Smb4KSharesMenu *shares_menu = findChild<Smb4KSharesMenu *>();
 
-  if ( shares_menu )
+  if (shares_menu)
   {
     shares_menu->refreshMenu();
   }
@@ -134,9 +139,9 @@ void Smb4KSystemTray::loadSettings()
 // SLOT IMPLEMENTATIONS
 /////////////////////////////////////////////////////////////////////////////
 
-void Smb4KSystemTray::slotMountDialog( bool /* checked */ )
+void Smb4KSystemTray::slotMountDialog(bool /* checked */)
 {
-  Smb4KMounter::self()->openMountDialog( associatedWidget() );
+  Smb4KMounter::self()->openMountDialog(associatedWidget());
 }
 
 
@@ -146,16 +151,16 @@ void Smb4KSystemTray::slotConfigDialog()
   // we do not create a new one but show the old instead:
   KConfigDialog *dlg = NULL;
 
-  if ( (dlg = KConfigDialog::exists( "ConfigDialog" )) && KConfigDialog::showDialog( "ConfigDialog" ) )
+  if ((dlg = KConfigDialog::exists("ConfigDialog")) && KConfigDialog::showDialog("ConfigDialog"))
   {
     // To make sure we do not connect the config dialog several times
     // to slotSettingsChanged(), we break the connection first and re-
     // establish it afterwards:
-    disconnect( dlg,  SIGNAL(settingsChanged(QString)),
-                this, SLOT(slotSettingsChanged(QString)) );
+    disconnect(dlg,  SIGNAL(settingsChanged(QString)),
+                this, SLOT(slotSettingsChanged(QString)));
 
-    connect( dlg,  SIGNAL(settingsChanged(QString)),
-             this, SLOT(slotSettingsChanged(QString)) );
+    connect(dlg,  SIGNAL(settingsChanged(QString)),
+             this, SLOT(slotSettingsChanged(QString)));
 
     return;
   }
@@ -165,30 +170,30 @@ void Smb4KSystemTray::slotConfigDialog()
   }
 
   // Load the configuration dialog:
-  KPluginLoader loader( "smb4kconfigdialog" );
+  KPluginLoader loader("smb4kconfigdialog");
   KPluginFactory *config_factory = loader.factory();
 
-  if ( config_factory )
+  if (config_factory)
   {
-    if ( associatedWidget() )
+    if (associatedWidget())
     {
-      dlg = config_factory->create<KConfigDialog>( associatedWidget() );
-      dlg->setObjectName( "ConfigDialog" );
+      dlg = config_factory->create<KConfigDialog>(associatedWidget());
+      dlg->setObjectName("ConfigDialog");
     }
     else
     {
-      dlg = config_factory->create<KConfigDialog>( contextMenu() );
-      dlg->setObjectName( "ConfigDialog" );
+      dlg = config_factory->create<KConfigDialog>(contextMenu());
+      dlg->setObjectName("ConfigDialog");
     }
 
     // ... and show it.
-    if ( dlg )
+    if (dlg)
     {
-      connect( dlg,  SIGNAL(settingsChanged(QString)),
-               this, SLOT(slotSettingsChanged(QString)) );
+      connect(dlg,  SIGNAL(settingsChanged(QString)),
+               this, SLOT(slotSettingsChanged(QString)));
 
-      connect( dlg,  SIGNAL(settingsChanged(QString)),
-               this, SIGNAL(settingsChanged(QString)) );
+      connect(dlg,  SIGNAL(settingsChanged(QString)),
+               this, SIGNAL(settingsChanged(QString)));
 
       dlg->show();
     }
@@ -199,12 +204,12 @@ void Smb4KSystemTray::slotConfigDialog()
   }
   else
   {
-    KMessageBox::error( 0, "<qt>"+loader.errorString()+"</qt>" );
+    KMessageBox::error(0, "<qt>"+loader.errorString()+"</qt>");
     return;
   }
 }
 
-void Smb4KSystemTray::slotSettingsChanged( const QString & )
+void Smb4KSystemTray::slotSettingsChanged(const QString &)
 {
   // Execute loadSettings():
   loadSettings();
@@ -214,15 +219,13 @@ void Smb4KSystemTray::slotSettingsChanged( const QString & )
 void Smb4KSystemTray::slotSetStatus()
 {
   // Set the status of the system tray icon.
-  if ( !mountedSharesList().isEmpty() || !workgroupsList().isEmpty() )
+  if (!mountedSharesList().isEmpty() || !workgroupsList().isEmpty())
   {
-    setStatus( KStatusNotifierItem::Active );
+    setStatus(KStatusNotifierItem::Active);
   }
   else
   {
-    setStatus( KStatusNotifierItem::Passive );
+    setStatus(KStatusNotifierItem::Passive);
   }
 }
 
-#include "smb4ksystemtray.moc"
-
